'''
Manage Azure NetApp Files (ANF) Snapshot Policy Resources.
'''
from .... pyaz_utils import _call_az

def show(account_name, resource_group, snapshot_policy_name):
    '''
    Get the specified ANF snapshot policy.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - snapshot_policy_name -- The name of the snapshot policy
    '''
    return _call_az("az netappfiles snapshot policy show", locals())


def list(account_name, resource_group):
    '''
    List the ANF snapshot policies for the specified account.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az netappfiles snapshot policy list", locals())


def volumes(account_name, resource_group, snapshot_policy_name):
    '''
    Get the all ANF volumes associated with snapshot policy.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - snapshot_policy_name -- The name of the snapshot policy
    '''
    return _call_az("az netappfiles snapshot policy volumes", locals())


def delete(account_name, resource_group, snapshot_policy_name):
    '''
    Delete the specified ANF snapshot policy.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - snapshot_policy_name -- The name of the snapshot policy
    '''
    return _call_az("az netappfiles snapshot policy delete", locals())


def update(account_name, location, resource_group, snapshot_policy_name, daily_hour=None, daily_minute=None, daily_snapshots=None, enabled=None, hourly_minute=None, hourly_snapshots=None, monthly_days=None, monthly_hour=None, monthly_minute=None, monthly_snapshots=None, weekly_day=None, weekly_hour=None, weekly_minute=None, weekly_snapshots=None):
    '''
    Update the specified ANF snapshot policy.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - snapshot_policy_name -- The name of the snapshot policy

    Optional Parameters:
    - daily_hour -- None
    - daily_minute -- None
    - daily_snapshots -- The amount of daily snapshots to keep
    - enabled -- The property to decide policy is enabled or not.
    - hourly_minute -- None
    - hourly_snapshots -- The amount of hourly snapshots to keep
    - monthly_days -- None
    - monthly_hour -- None
    - monthly_minute -- None
    - monthly_snapshots -- The amount of monthly snapshots to keep
    - weekly_day -- None
    - weekly_hour -- None
    - weekly_minute -- None
    - weekly_snapshots -- The amount of weekly snapshots to keep
    '''
    return _call_az("az netappfiles snapshot policy update", locals())


def create(account_name, location, resource_group, snapshot_policy_name, daily_hour=None, daily_minute=None, daily_snapshots=None, enabled=None, hourly_minute=None, hourly_snapshots=None, monthly_days=None, monthly_hour=None, monthly_minute=None, monthly_snapshots=None, tags=None, weekly_day=None, weekly_hour=None, weekly_minute=None, weekly_snapshots=None):
    '''
    Create a new Azure NetApp Files (ANF) snapshot policy.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - snapshot_policy_name -- The name of the snapshot policy

    Optional Parameters:
    - daily_hour -- None
    - daily_minute -- None
    - daily_snapshots -- The amount of daily snapshots to keep
    - enabled -- The property to decide policy is enabled or not.
    - hourly_minute -- None
    - hourly_snapshots -- The amount of hourly snapshots to keep
    - monthly_days -- None
    - monthly_hour -- None
    - monthly_minute -- None
    - monthly_snapshots -- The amount of monthly snapshots to keep
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - weekly_day -- None
    - weekly_hour -- None
    - weekly_minute -- None
    - weekly_snapshots -- The amount of weekly snapshots to keep
    '''
    return _call_az("az netappfiles snapshot policy create", locals())




from ... pyaz_utils import _call_az

def show(origin_group_name, profile_name, resource_group):
    '''
    

    Required Parameters:
    - origin_group_name -- Name of the origin group.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az afd origin-group show", locals())


def list(profile_name, resource_group):
    '''
    

    Required Parameters:
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az afd origin-group list", locals())


def create(additional_latency_in_milliseconds, origin_group_name, probe_path, probe_protocol, probe_request_type, profile_name, resource_group, sample_size, successful_samples_required, probe_interval_in_seconds=None):
    '''
    Creates a new origin group within the specified profile.

    Required Parameters:
    - additional_latency_in_milliseconds -- The additional latency in milliseconds for probes to fall into the lowest latency bucket.
    - origin_group_name -- Name of the origin group.
    - probe_path -- The path relative to the origin that is used to determine the health of the origin.
    - probe_protocol -- Protocol to use for health probe.
    - probe_request_type -- The type of health probe request that is made.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - sample_size -- The number of samples to consider for load balancing decisions.
    - successful_samples_required -- The number of samples within the sample period that must succeed.

    Optional Parameters:
    - probe_interval_in_seconds -- The number of seconds between health probes.
    '''
    return _call_az("az afd origin-group create", locals())


def update(origin_group_name, profile_name, resource_group, additional_latency_in_milliseconds=None, probe_interval_in_seconds=None, probe_path=None, probe_protocol=None, probe_request_type=None, sample_size=None, successful_samples_required=None):
    '''
    Creates a new origin group within the specified profile.

    Required Parameters:
    - origin_group_name -- Name of the origin group.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - additional_latency_in_milliseconds -- The additional latency in milliseconds for probes to fall into the lowest latency bucket.
    - probe_interval_in_seconds -- The number of seconds between health probes.
    - probe_path -- The path relative to the origin that is used to determine the health of the origin.
    - probe_protocol -- Protocol to use for health probe.
    - probe_request_type -- The type of health probe request that is made.
    - sample_size -- The number of samples to consider for load balancing decisions.
    - successful_samples_required -- The number of samples within the sample period that must succeed.
    '''
    return _call_az("az afd origin-group update", locals())


def delete(origin_group_name, profile_name, resource_group, yes=None):
    '''
    Deletes an existing origin group within the specified profile.

    Required Parameters:
    - origin_group_name -- Name of the origin group.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az afd origin-group delete", locals())




from ...... pyaz_utils import _call_az

def set(address_prefix, circuit_name, name, peering_name, resource_group):
    '''
    Set connection config to ExpressRoute circuit connection.

    Required Parameters:
    - address_prefix -- /125 IP address space to carve out customer addresses for global reach.
    - circuit_name -- ExpressRoute circuit name.
    - name -- Name of the peering connection.
    - peering_name -- Name of BGP peering (i.e. AzurePrivatePeering).
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network express-route peering connection ipv6-config set", locals())


def remove(circuit_name, name, peering_name, resource_group):
    '''
    Remove connection config to ExpressRoute circuit connection.

    Required Parameters:
    - circuit_name -- ExpressRoute circuit name.
    - name -- Name of the peering connection.
    - peering_name -- Name of BGP peering (i.e. AzurePrivatePeering).
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network express-route peering connection ipv6-config remove", locals())




'''
Manage Azure Search services.
'''
from ... pyaz_utils import _call_az

def list(resource_group):
    '''
    

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az search service list", locals())


def show(name, resource_group):
    '''
    

    Required Parameters:
    - name -- The name of the search service.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az search service show", locals())


def delete(name, resource_group, yes=None):
    '''
    

    Required Parameters:
    - name -- The name of the search service.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az search service delete", locals())


def update(name, resource_group, add=None, force_string=None, identity_type=None, ip_rules=None, no_wait=None, partition_count=None, public_network_access=None, remove=None, replica_count=None, set=None):
    '''
    Update partition and replica of the given search service.

    Required Parameters:
    - name -- The name of the search service.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - identity_type -- The identity type; possible values include: "None", "SystemAssigned".
    - ip_rules -- Public IP(v4) addresses or CIDR ranges to the search service, seperated by comma(',') or semicolon(';'); If spaces (' '), ',' or ';' is provided, any existing IP rule will be nullified and no public IP rule is applied. These IP rules are applicable only when public_network_access is "enabled".
    - no_wait -- Do not wait for the long-running operation to finish.
    - partition_count -- Number of partitions in the search service.
    - public_network_access -- Public accessibility to the search service; allowed values are "enabled" or "disabled".
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - replica_count -- Number of replicas in the search service.
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az search service update", locals())


def create(name, resource_group, sku, identity_type=None, ip_rules=None, location=None, no_wait=None, partition_count=None, public_network_access=None, replica_count=None):
    '''
    Creates a Search service in the given resource group.

    Required Parameters:
    - name -- The name of the search service.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - sku -- Search Service SKU

    Optional Parameters:
    - identity_type -- The identity type; possible values include: "None", "SystemAssigned".
    - ip_rules -- Public IP(v4) addresses or CIDR ranges to the search service, seperated by comma or semicolon; these IP rules are applicable only when --public-network-access is "enabled".
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - no_wait -- Do not wait for the long-running operation to finish.
    - partition_count -- Number of partitions in the search service.
    - public_network_access -- Public accessibility to the search service; allowed values are "enabled" or "disabled".
    - replica_count -- Number of replicas in the search service.
    '''
    return _call_az("az search service create", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Wait for async service operations.

    Required Parameters:
    - name -- The name of the search service.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az search service wait", locals())




'''
Manage credentials for a task. Please see https://aka.ms/acr/tasks/cross-registry-authentication for more information.
'''
from .... pyaz_utils import _call_az

def add(login_server, name, registry, password=None, resource_group=None, use_identity=None, username=None):
    '''
    Add a custom registry login credential to the task

    Required Parameters:
    - login_server -- The login server of the custom registry. For instance, 'myregistry.azurecr.io'.
    - name -- The name of the task.
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - password -- The password to login to the custom registry. This can be plain text or a key vault secret URI.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - use_identity -- The task managed identity used for the credential. Use '[system]' to refer to the system-assigned identity or a client id to refer to a user-assigned identity. Please see https://aka.ms/acr/tasks/cross-registry-authentication for more information.
    - username -- The username to login to the custom registry. This can be plain text or a key vault secret URI.
    '''
    return _call_az("az acr task credential add", locals())


def update(login_server, name, registry, password=None, resource_group=None, use_identity=None, username=None):
    '''
    Update the registry login credential for a task.

    Required Parameters:
    - login_server -- The login server of the custom registry. For instance, 'myregistry.azurecr.io'.
    - name -- The name of the task.
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - password -- The password to login to the custom registry. This can be plain text or a key vault secret URI.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - use_identity -- The task managed identity used for the credential. Use '[system]' to refer to the system-assigned identity or a client id to refer to a user-assigned identity. Please see https://aka.ms/acr/tasks/cross-registry-authentication for more information.
    - username -- The username to login to the custom registry. This can be plain text or a key vault secret URI.
    '''
    return _call_az("az acr task credential update", locals())


def remove(login_server, name, registry, resource_group=None):
    '''
    Remove credential for a task.

    Required Parameters:
    - login_server -- The login server of the custom registry. For instance, 'myregistry.azurecr.io'.
    - name -- The name of the task.
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr task credential remove", locals())


def list(name, registry, resource_group=None):
    '''
    List all the custom registry credentials for task.

    Required Parameters:
    - name -- The name of the task.
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr task credential list", locals())




'''
Manage order with databoxedge
'''
from ... pyaz_utils import _call_az

def list(device_name, resource_group):
    '''
    List all the orders related to a Data Box Edge/Data Box Gateway device.

    Required Parameters:
    - device_name -- The device name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az databoxedge order list", locals())


def show(device_name, resource_group):
    '''
    Get a specific order by name.

    Required Parameters:
    - device_name -- The device name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az databoxedge order show", locals())


def create(address_line1, city, company_name, contact_person, country, device_name, email_list, phone, postal_code, resource_group, state, status, address_line2=None, address_line3=None, comments=None, no_wait=None):
    '''
    Create an order.

    Required Parameters:
    - address_line1 -- The address line1.
    - city -- The city name.
    - company_name -- The name of the company.
    - contact_person -- The contact person name.
    - country -- The country name.
    - device_name -- The order details of a device.
    - email_list -- The email list.
    - phone -- The phone number.
    - postal_code -- The postal code.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - state -- The state name.
    - status -- Status of the order as per the allowed status types.

    Optional Parameters:
    - address_line2 -- The address line2.
    - address_line3 -- The address line3.
    - comments -- Comments related to this status change.
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az databoxedge order create", locals())


def update(device_name, resource_group, add=None, address_line1=None, address_line2=None, address_line3=None, city=None, comments=None, company_name=None, contact_person=None, country=None, email_list=None, force_string=None, no_wait=None, phone=None, postal_code=None, remove=None, set=None, state=None, status=None):
    '''
    Update an order.

    Required Parameters:
    - device_name -- The order details of a device.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - address_line1 -- The address line1.
    - address_line2 -- The address line2.
    - address_line3 -- The address line3.
    - city -- The city name.
    - comments -- Comments related to this status change.
    - company_name -- The name of the company.
    - contact_person -- The contact person name.
    - country -- The country name.
    - email_list -- The email list.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - no_wait -- Do not wait for the long-running operation to finish.
    - phone -- The phone number.
    - postal_code -- The postal code.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - state -- The state name.
    - status -- Status of the order as per the allowed status types.
    '''
    return _call_az("az databoxedge order update", locals())


def delete(device_name, resource_group, no_wait=None, yes=None):
    '''
    Delete the order related to the device.

    Required Parameters:
    - device_name -- The device name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az databoxedge order delete", locals())


def wait(device_name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the databoxedge order is met.

    Required Parameters:
    - device_name -- The device name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az databoxedge order wait", locals())




'''
View security tasks (recommendations).
'''
from ... pyaz_utils import _call_az

def list(resource_group=None):
    '''
    List security tasks (recommendations).

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az security task list", locals())


def show(name, resource_group=None):
    '''
    shows a security task (recommendation).

    Required Parameters:
    - name -- name of the resource to be fetched

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az security task show", locals())




'''
Commands to manage clusters.
'''
from ... pyaz_utils import _call_az
from . import file, node


def create(name, resource_group, workspace, afs_mount_path=None, afs_name=None, bfs_mount_path=None, bfs_name=None, config_file=None, custom_image=None, generate_ssh_keys=None, image=None, max=None, min=None, nfs=None, nfs_mount_path=None, password=None, setup_task=None, setup_task_output=None, ssh_key=None, storage_account_key=None, storage_account_name=None, subnet=None, target=None, use_auto_storage=None, user_name=None, vm_priority=None, vm_size=None):
    '''
    Create a cluster.

    Required Parameters:
    - name -- Name of cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace -- Name of workspace.

    Optional Parameters:
    - afs_mount_path -- Relative mount path for Azure File share. The file share will be available at $AZ_BATCHAI_MOUNT_ROOT/<relative_mount_path> folder.
    - afs_name -- Name of Azure File Share to be mounted on each cluster node. Must be used in conjunction with --storage-account-name. Multiple shares can be mounted using configuration file (see --config-file option).
    - bfs_mount_path -- Relative mount path for Azure Storage container. The container will be available at $AZ_BATCHAI_MOUNT_ROOT/<relative_mount_path> folder.
    - bfs_name -- Name of Azure Storage container to be mounted on each cluster node. Must be used in conjunction with --storage-account-name. Multiple containers can be mounted using configuration file (see --config-file option).
    - config_file -- A path to a json file containing cluster create parameters (json representation of azure.mgmt.batchai.models.ClusterCreateParameters).
    - custom_image -- ARM ID of a virtual machine image to be used for nodes creation. Note, you need to provide --image containing information about the base image used for this image creation.
    - generate_ssh_keys -- Generate SSH public and private key files in ~/.ssh directory (if missing).
    - image -- Operation system image for cluster nodes. The value may contain an alias (UbuntuLTS, UbuntuDSVM) or specify image details in the form "publisher:offer:sku:version". If image configuration is not provided via command line or configuration file, Batch AI will choose default OS image
    - max -- Max nodes count for the auto-scale cluster.
    - min -- Min nodes count for the auto-scale cluster.
    - nfs -- Name or ARM ID of a file server to be mounted on each cluster node. You need to provide full ARM ID if the file server belongs to a different workspace. Multiple NFS can be mounted using configuration file (see --config-file option).
    - nfs_mount_path -- Relative mount path for NFS. The NFS will be available at $AZ_BATCHAI_MOUNT_ROOT/<relative_mount_path> folder.
    - password -- Optional password for the admin user account to be created on each compute node.
    - setup_task -- A command line which should be executed on each compute node when it's got allocated or rebooted. The task is executed in a bash subshell under root account.
    - setup_task_output -- Directory path to store where setup-task's logs. Note, Batch AI will create several helper directories under this path. The created directories are reported as stdOutErrPathSuffix by 'az cluster show' command.
    - ssh_key -- Optional SSH public key value or path. If ommited and no password specified, default SSH key (~/.ssh/id_rsa.pub) will be used.
    - storage_account_key -- Storage account key. Required if the storage account belongs to a different subscription. Can be specified using AZURE_BATCHAI_STORAGE_KEY environment variable.
    - storage_account_name -- Storage account name for Azure File Shares and/or Azure Storage Containers to be mounted on each cluster node. Can be specified using AZURE_BATCHAI_STORAGE_ACCOUNT environment variable.
    - subnet -- ARM ID of a virtual network subnet to put the cluster in.
    - target -- Number of nodes which should be allocated immediately after cluster creation. If the cluster is in auto-scale mode, BatchAI can change the number of nodes later based on number of running and queued jobs.
    - use_auto_storage -- If provided, the command will create a storage account in a new or existing resource group named "batchaiautostorage". It will also create Azure File Share with name "batchaishare", Azure Blob Container with name "batchaicontainer". The File Share and Blob Container will be mounted on each cluster node at $AZ_BATCHAI_MOUNT_ROOT/autoafs and $AZ_BATCHAI_MOUNT_ROOT/autobfs. If the resource group already exists and contains an approapriate storage account belonging to the same region as cluster, this command will reuse existing storage account.
    - user_name -- Name of admin user account to be created on each compute node. If the value is not provided and no user configuration is provided in the config file, current user's name will be used.
    - vm_priority -- VM priority.
    - vm_size -- VM size for cluster nodes (e.g. Standard_NC6 for 1 GPU node)
    '''
    return _call_az("az batchai cluster create", locals())


def delete(name, resource_group, workspace, no_wait=None, yes=None):
    '''
    Delete a cluster.

    Required Parameters:
    - name -- Name of cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace -- Name of workspace.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az batchai cluster delete", locals())


def show(name, resource_group, workspace):
    '''
    Show information about a cluster.

    Required Parameters:
    - name -- Name of cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace -- Name of workspace.
    '''
    return _call_az("az batchai cluster show", locals())


def list(resource_group, workspace):
    '''
    List clusters.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace -- Name of workspace.
    '''
    return _call_az("az batchai cluster list", locals())


def resize(name, resource_group, target, workspace):
    '''
    Resize a cluster.

    Required Parameters:
    - name -- Name of cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - target -- Target number of compute nodes.
    - workspace -- Name of workspace.
    '''
    return _call_az("az batchai cluster resize", locals())


def auto_scale(max, min, name, resource_group, workspace):
    '''
    Set auto-scale parameters for a cluster.

    Required Parameters:
    - max -- Maximum number of nodes.
    - min -- Minimum number of nodes.
    - name -- Name of cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace -- Name of workspace.
    '''
    return _call_az("az batchai cluster auto-scale", locals())




'''
Manage Azure Cosmos DB MongoDB collections.
'''
from .... pyaz_utils import _call_az
from . import throughput


def create(account_name, database_name, name, resource_group, analytical_storage_ttl=None, idx=None, max_throughput=None, shard=None, throughput=None):
    '''
    Create an MongoDB collection under an Azure Cosmos DB MongoDB database.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - database_name -- Database name.
    - name -- Collection name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - analytical_storage_ttl -- Analytical TTL, when analytical storage is enabled.
    - idx -- Indexes, you can enter it as a string or as a file, e.g., --idx @indexes-file.json or --idx "[{\"key\": {\"keys\": [\"_ts\"]},\"options\": {\"expireAfterSeconds\": 1000}}, {\"key\": {\"keys\": [\"user_id\", \"user_address\"]}, \"options\": {\"unique\": \"true\"}}]"

    - max_throughput -- The maximum throughput resource can scale to (RU/s). Provided when the resource is autoscale enabled. The minimum value can be 4000 (RU/s)
    - shard -- Sharding key path.
    - throughput -- The throughput of MongoDB collection (RU/s). Default value is 400. Omit this parameter if the database has shared throughput unless the collection should have dedicated throughput.
    '''
    return _call_az("az cosmosdb mongodb collection create", locals())


def update(account_name, database_name, name, resource_group, analytical_storage_ttl=None, idx=None):
    '''
    Update an MongoDB collection under an Azure Cosmos DB MongoDB database.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - database_name -- Database name.
    - name -- Collection name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - analytical_storage_ttl -- Analytical TTL, when analytical storage is enabled.
    - idx -- Indexes, you can enter it as a string or as a file, e.g., --idx @indexes-file.json or --idx "[{\"key\": {\"keys\": [\"_ts\"]},\"options\": {\"expireAfterSeconds\": 1000}}, {\"key\": {\"keys\": [\"user_id\", \"user_address\"]}, \"options\": {\"unique\": \"true\"}}]"

    '''
    return _call_az("az cosmosdb mongodb collection update", locals())


def exists(account_name, database_name, name, resource_group):
    '''
    

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - database_name -- Database name.
    - name -- Collection name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cosmosdb mongodb collection exists", locals())


def list(account_name, database_name, resource_group):
    '''
    List the MongoDB collections under an Azure Cosmos DB MongoDB database.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - database_name -- Database name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cosmosdb mongodb collection list", locals())


def show(account_name, database_name, name, resource_group):
    '''
    Show the details of a MongoDB collection under an Azure Cosmos DB MongoDB database.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - database_name -- Database name.
    - name -- Collection name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cosmosdb mongodb collection show", locals())


def delete(account_name, database_name, name, resource_group, yes=None):
    '''
    Delete the MongoDB collection under an Azure Cosmos DB MongoDB database.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - database_name -- Database name.
    - name -- Collection name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az cosmosdb mongodb collection delete", locals())




'''
Manage Batch pools.
'''
from ... pyaz_utils import _call_az
from . import all_statistics, autoscale, node_counts, supported_images, usage_metrics


def create(account_endpoint=None, account_key=None, account_name=None, application_licenses=None, application_package_references=None, auto_scale_formula=None, certificate_references=None, disk_encryption_targets=None, enable_inter_node_communication=None, id=None, image=None, json_file=None, metadata=None, node_agent_sku_id=None, offer=None, os_family=None, os_version=None, policy=None, publisher=None, resize_timeout=None, sku=None, start_task_command_line=None, start_task_resource_files=None, start_task_wait_for_success=None, target_dedicated_nodes=None, target_low_priority_nodes=None, targets=None, task_slots_per_node=None, version=None, virtual_machine_image_id=None, vm_size=None):
    '''
    Create a Batch pool in an account. When creating a pool, choose arguments from either Cloud Services Configuration or Virtual Machine Configuration.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - application_licenses -- The list of application licenses must be a subset of available Batch service application licenses. If a license is requested which is not supported, Pool creation will fail. Space-separated values.
    - application_package_references -- Changes to Package references affect all new Nodes joining the Pool, but do not affect Compute Nodes that are already in the Pool until they are rebooted or reimaged. There is a maximum of 10 Package references on any given Pool. Space-separated application IDs with optional version in 'id[#version]' format.
    - auto_scale_formula -- A formula for the desired number of compute nodes in the pool. The formula is checked for validity before the pool is created. If the formula is not valid, the Batch service rejects the request with detailed error information. For more information about specifying this formula, see https://azure.microsoft.com/documentation/articles/batch-automatic-scaling/.
    - certificate_references -- For Windows Nodes, the Batch service installs the Certificates to the specified Certificate store and location. For Linux Compute Nodes, the Certificates are stored in a directory inside the Task working directory and an environment variable AZ_BATCH_CERTIFICATES_DIR is supplied to the Task to query for this location. For Certificates with visibility of 'remoteUser', a 'certs' directory is created in the user's home directory (e.g., /home/{user-name}/certs) and Certificates are placed in that directory. Space-separated certificate thumbprints.
    - disk_encryption_targets -- A space separated list of DiskEncryptionTargets. current possible values include OsDisk and TemporaryDisk.
    - enable_inter_node_communication -- Whether the Pool permits direct communication between Compute Nodes. Enabling inter-node communication limits the maximum size of the Pool due to deployment restrictions on the Compute Nodes of the Pool. This may result in the Pool not reaching its desired size. The default value is false. True if flag present.
    - id -- Required. The ID can contain any combination of alphanumeric characters including hyphens and underscores, and cannot contain more than 64 characters. The ID is case-preserving and case-insensitive (that is, you may not have two Pool IDs within an Account that differ only by case).
    - image -- OS image reference. This can be either 'publisher:offer:sku[:version]' format, or a fully qualified ARM image id of the form '/subscriptions/{subscriptionId}/resourceGroups/{resourceGroup}/providers/Microsoft.Compute/images/{imageName}'. If 'publisher:offer:sku[:version]' format, version is optional and if omitted latest will be used. Valid values can be retrieved via 'az batch pool supported-images list'. For example: 'MicrosoftWindowsServer:WindowsServer:2012-R2-Datacenter:latest'
    - json_file -- A file containing the pool specification in JSON (formatted to match the respective REST API body). If this parameter is specified, all 'Pool Arguments' are ignored.
    - metadata -- The Batch service does not assign any meaning to metadata; it is solely for the use of user code. Space-separated values in 'key=value' format.
    - node_agent_sku_id -- Required. The Batch Compute Node agent is a program that runs on each Compute Node in the Pool, and provides the command-and-control interface between the Compute Node and the Batch service. There are different implementations of the Compute Node agent, known as SKUs, for different operating systems. You must specify a Compute Node agent SKU which matches the selected Image reference. To get the list of supported Compute Node agent SKUs along with their list of verified Image references, see the 'List supported Compute Node agent SKUs' operation.
    - offer -- ==SUPPRESS==
    - os_family -- Required. Possible values are: 2 - OS Family 2, equivalent to Windows Server 2008 R2 SP1. 3 - OS Family 3, equivalent to Windows Server 2012. 4 - OS Family 4, equivalent to Windows Server 2012 R2. 5 - OS Family 5, equivalent to Windows Server 2016. 6 - OS Family 6, equivalent to Windows Server 2019. For more information, see Azure Guest OS Releases (https://azure.microsoft.com/documentation/articles/cloud-services-guestos-update-matrix/#releases).
    - os_version -- The default value is * which specifies the latest operating system version for the specified OS family.
    - policy -- Node placement Policy type on Batch Pools. Allocation policy used by Batch Service to provision the nodes. If not specified, Batch will use the regional policy.
    - publisher -- ==SUPPRESS==
    - resize_timeout -- This timeout applies only to manual scaling; it has no effect when enableAutoScale is set to true. The default value is 15 minutes. The minimum value is 5 minutes. If you specify a value less than 5 minutes, the Batch service returns an error; if you are calling the REST API directly, the HTTP status code is 400 (Bad Request). Expected format is an ISO-8601 duration.
    - sku -- ==SUPPRESS==
    - start_task_command_line -- Required. The command line does not run under a shell, and therefore cannot take advantage of shell features such as environment variable expansion. If you want to take advantage of such features, you should invoke the shell in the command line, for example using "cmd /c MyCommand" in Windows or "/bin/sh -c MyCommand" in Linux. If the command line refers to file paths, it should use a relative path (relative to the Task working directory), or use the Batch provided environment variable (https://docs.microsoft.com/en-us/azure/batch/batch-compute-node-environment-variables).
    - start_task_resource_files -- Files listed under this element are located in the Task's working directory. Space-separated resource references in filename=httpurl format.
    - start_task_wait_for_success -- Whether the Batch service should wait for the StartTask to complete successfully (that is, to exit with exit code 0) before scheduling any Tasks on the Compute Node. If true and the StartTask fails on a Node, the Batch service retries the StartTask up to its maximum retry count (maxTaskRetryCount). If the Task has still not completed successfully after all retries, then the Batch service marks the Node unusable, and will not schedule Tasks to it. This condition can be detected via the Compute Node state and failure info details. If false, the Batch service will not wait for the StartTask to complete. In this case, other Tasks can start executing on the Compute Node while the StartTask is still running; and even if the StartTask fails, new Tasks will continue to be scheduled on the Compute Node. The default is true. True if flag present.
    - target_dedicated_nodes -- The desired number of dedicated Compute Nodes in the Pool. This property must not be specified if enableAutoScale is set to true. If enableAutoScale is set to false, then you must set either targetDedicatedNodes, targetLowPriorityNodes, or both.
    - target_low_priority_nodes -- The desired number of low-priority Compute Nodes in the Pool. This property must not be specified if enableAutoScale is set to true. If enableAutoScale is set to false, then you must set either targetDedicatedNodes, targetLowPriorityNodes, or both.
    - targets -- If omitted, no disks on the compute nodes in the pool will be encrypted. On Linux pool, only "TemporaryDisk" is supported; on Windows pool, "OsDisk" and "TemporaryDisk" must be specified. Space seperated target disks to be encrypted. Values can either be OsDisk or TemporaryDisk
    - task_slots_per_node -- The number of task slots that can be used to run concurrent tasks on a single compute node in the pool. The default value is 1. The maximum value is the smaller of 4 times the number of cores of the vmSize of the pool or 256.
    - version -- ==SUPPRESS==
    - virtual_machine_image_id -- ==SUPPRESS==
    - vm_size -- Required. For information about available sizes of virtual machines for Cloud Services Pools (pools created with cloudServiceConfiguration), see Sizes for Cloud Services (https://azure.microsoft.com/documentation/articles/cloud-services-sizes-specs/). Batch supports all Cloud Services VM sizes except ExtraSmall, A1V2 and A2V2. For information about available VM sizes for Pools using Images from the Virtual Machines Marketplace (pools created with virtualMachineConfiguration) see Sizes for Virtual Machines (Linux) (https://azure.microsoft.com/documentation/articles/virtual-machines-linux-sizes/) or Sizes for Virtual Machines (Windows) (https://azure.microsoft.com/documentation/articles/virtual-machines-windows-sizes/). Batch supports all Azure VM sizes except STANDARD_A0 and those with premium storage (STANDARD_GS, STANDARD_DS, and STANDARD_DSV2 series).
    '''
    return _call_az("az batch pool create", locals())


def list(account_endpoint=None, account_key=None, account_name=None, expand=None, filter=None, select=None):
    '''
    

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - expand -- An OData $expand clause.
    - filter -- An OData $filter clause. For more information on constructing this filter, see https://docs.microsoft.com/en-us/rest/api/batchservice/odata-filters-in-batch#list-pools.
    - select -- An OData $select clause.
    '''
    return _call_az("az batch pool list", locals())


def delete(pool_id, account_endpoint=None, account_key=None, account_name=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, yes=None):
    '''
    

    Required Parameters:
    - pool_id -- The ID of the Pool to delete.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - if_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service exactly matches the value specified by the client.
    - if_modified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has been modified since the specified time.
    - if_none_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service does not match the value specified by the client.
    - if_unmodified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has not been modified since the specified time.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az batch pool delete", locals())


def show(pool_id, account_endpoint=None, account_key=None, account_name=None, expand=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, select=None):
    '''
    

    Required Parameters:
    - pool_id -- The ID of the Pool to get.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - expand -- An OData $expand clause.
    - if_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service exactly matches the value specified by the client.
    - if_modified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has been modified since the specified time.
    - if_none_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service does not match the value specified by the client.
    - if_unmodified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has not been modified since the specified time.
    - select -- An OData $select clause.
    '''
    return _call_az("az batch pool show", locals())


def set(pool_id, account_endpoint=None, account_key=None, account_name=None, application_package_references=None, certificate_references=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, json_file=None, metadata=None, start_task_command_line=None, start_task_environment_settings=None, start_task_max_task_retry_count=None, start_task_resource_files=None, start_task_wait_for_success=None):
    '''
    Update the properties of a Batch pool. Updating a property in a subgroup will reset the unspecified properties of that group.

    Required Parameters:
    - pool_id -- The ID of the Pool to update.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - application_package_references -- Changes to Package references affect all new Nodes joining the Pool, but do not affect Compute Nodes that are already in the Pool until they are rebooted or reimaged. If this element is present, it replaces any existing Package references. If you specify an empty collection, then all Package references are removed from the Pool. If omitted, any existing Package references are left unchanged. Space-separated application IDs with optional version in 'id[#version]' format.
    - certificate_references -- If this element is present, it replaces any existing Certificate references configured on the Pool. If omitted, any existing Certificate references are left unchanged. For Windows Nodes, the Batch service installs the Certificates to the specified Certificate store and location. For Linux Compute Nodes, the Certificates are stored in a directory inside the Task working directory and an environment variable AZ_BATCH_CERTIFICATES_DIR is supplied to the Task to query for this location. For Certificates with visibility of 'remoteUser', a 'certs' directory is created in the user's home directory (e.g., /home/{user-name}/certs) and Certificates are placed in that directory. Space-separated certificate thumbprints.
    - if_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service exactly matches the value specified by the client.
    - if_modified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has been modified since the specified time.
    - if_none_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service does not match the value specified by the client.
    - if_unmodified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has not been modified since the specified time.
    - json_file -- A file containing the pool patch parameter specification in JSON (formatted to match the respective REST API body). If this parameter is specified, all 'Pool Arguments' are ignored.
    - metadata -- If this element is present, it replaces any existing metadata configured on the Pool. If you specify an empty collection, any metadata is removed from the Pool. If omitted, any existing metadata is left unchanged. Space-separated values in 'key=value' format.
    - start_task_command_line -- Required. The command line does not run under a shell, and therefore cannot take advantage of shell features such as environment variable expansion. If you want to take advantage of such features, you should invoke the shell in the command line, for example using "cmd /c MyCommand" in Windows or "/bin/sh -c MyCommand" in Linux. If the command line refers to file paths, it should use a relative path (relative to the Task working directory), or use the Batch provided environment variable (https://docs.microsoft.com/en-us/azure/batch/batch-compute-node-environment-variables).
    - start_task_environment_settings --  Space-separated values in 'key=value' format.
    - start_task_max_task_retry_count -- The maximum number of times the Task may be retried. The Batch service retries a Task if its exit code is nonzero. Note that this value specifically controls the number of retries. The Batch service will try the Task once, and may then retry up to this limit. For example, if the maximum retry count is 3, Batch tries the Task up to 4 times (one initial try and 3 retries). If the maximum retry count is 0, the Batch service does not retry the Task. If the maximum retry count is -1, the Batch service retries the Task without limit.
    - start_task_resource_files -- Files listed under this element are located in the Task's working directory. Space-separated resource references in filename=httpurl format.
    - start_task_wait_for_success -- Whether the Batch service should wait for the StartTask to complete successfully (that is, to exit with exit code 0) before scheduling any Tasks on the Compute Node. If true and the StartTask fails on a Node, the Batch service retries the StartTask up to its maximum retry count (maxTaskRetryCount). If the Task has still not completed successfully after all retries, then the Batch service marks the Node unusable, and will not schedule Tasks to it. This condition can be detected via the Compute Node state and failure info details. If false, the Batch service will not wait for the StartTask to complete. In this case, other Tasks can start executing on the Compute Node while the StartTask is still running; and even if the StartTask fails, new Tasks will continue to be scheduled on the Compute Node. The default is true. Specify either 'true' or 'false' to update the property.
    '''
    return _call_az("az batch pool set", locals())


def reset(pool_id, account_endpoint=None, account_key=None, account_name=None, application_package_references=None, certificate_references=None, json_file=None, metadata=None, start_task_command_line=None, start_task_environment_settings=None, start_task_max_task_retry_count=None, start_task_wait_for_success=None):
    '''
    Update the properties of a Batch pool. Unspecified properties which can be updated are reset to their defaults.

    Required Parameters:
    - pool_id -- The ID of the pool to update.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- The Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- The Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - application_package_references -- Required. The list replaces any existing Application Package references on the Pool. Changes to Application Package references affect all new Compute Nodes joining the Pool, but do not affect Compute Nodes that are already in the Pool until they are rebooted or reimaged. There is a maximum of 10 Application Package references on any given Pool. If omitted, or if you specify an empty collection, any existing Application Packages references are removed from the Pool. A maximum of 10 references may be specified on a given Pool.
    - certificate_references -- Required. This list replaces any existing Certificate references configured on the Pool. If you specify an empty collection, any existing Certificate references are removed from the Pool. For Windows Nodes, the Batch service installs the Certificates to the specified Certificate store and location. For Linux Compute Nodes, the Certificates are stored in a directory inside the Task working directory and an environment variable AZ_BATCH_CERTIFICATES_DIR is supplied to the Task to query for this location. For Certificates with visibility of 'remoteUser', a 'certs' directory is created in the user's home directory (e.g., /home/{user-name}/certs) and Certificates are placed in that directory.
    - json_file -- The file containing pool update properties parameter specification in JSON(formatted to match REST API request body). If this parameter is specified, all 'Pool Update Properties Parameter Arguments' are ignored.
    - metadata -- Required. This list replaces any existing metadata configured on the Pool. If omitted, or if you specify an empty collection, any existing metadata is removed from the Pool.
    - start_task_command_line -- The command line of the start task. The command line does not run under a shell, and therefore cannot take advantage of shell features such as environment variable expansion. If you want to take advantage of such features, you should invoke the shell in the command line, for example using "cmd /c MyCommand" in Windows or "/bin/sh -c MyCommand" in Linux.
    - start_task_environment_settings -- A list of environment variable settings for the start task. Space-separated values in 'key=value' format.
    - start_task_max_task_retry_count -- The maximum number of times the task may be retried.
    - start_task_wait_for_success -- Whether the Batch service should wait for the start task to complete successfully (that is, to exit with exit code 0) before scheduling any tasks on the compute node. True if flag present, otherwise defaults to False.
    '''
    return _call_az("az batch pool reset", locals())


def resize(pool_id, abort=None, account_endpoint=None, account_key=None, account_name=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, node_deallocation_option=None, resize_timeout=None, target_dedicated_nodes=None, target_low_priority_nodes=None):
    '''
    Resize or stop resizing a Batch pool.

    Required Parameters:
    - pool_id -- The ID of the pool.

    Optional Parameters:
    - abort -- Stop the pool resize operation.
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- The Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- The Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - if_match -- The operation will be performed only if the resource's current ETag exactly matches the specified value.
    - if_modified_since -- The operation will be performed only if the resource has been modified since the specified timestamp.
    - if_none_match -- The operation will not be performed only if the resource's current ETag exactly matches the specified value.
    - if_unmodified_since -- The operation will not be performed only if the resource has been modified since the specified timestamp.
    - node_deallocation_option -- When nodes may be removed from the pool, if the pool size is decreasing.
    - resize_timeout -- The default value is 15 minutes. The minimum value is 5 minutes. If you specify a value less than 5 minutes, the Batch service returns an error; if you are calling the REST API directly, the HTTP status code is 400 (Bad Request).
    - target_dedicated_nodes -- The desired number of dedicated Compute Nodes in the Pool.
    - target_low_priority_nodes -- The desired number of low-priority Compute Nodes in the Pool.
    '''
    return _call_az("az batch pool resize", locals())




'''
Manage groupings of virtual machines in an Azure Virtual Machine Scale Set (VMSS).
'''
from .. pyaz_utils import _call_az
from . import application, diagnostics, disk, encryption, extension, identity, nic, rolling_upgrade, run_command


def create(name, resource_group, accelerated_networking=None, admin_password=None, admin_username=None, app_gateway=None, app_gateway_capacity=None, app_gateway_sku=None, app_gateway_subnet_address_prefix=None, asgs=None, assign_identity=None, authentication_type=None, automatic_repairs_grace_period=None, backend_pool_name=None, backend_port=None, capacity_reservation_group=None, computer_name_prefix=None, custom_data=None, data_disk_caching=None, data_disk_encryption_sets=None, data_disk_iops=None, data_disk_mbps=None, data_disk_sizes_gb=None, disable_overprovision=None, dns_servers=None, edge_zone=None, enable_agent=None, enable_auto_update=None, enable_cross_zone_upgrade=None, enable_spot_restore=None, encryption_at_host=None, ephemeral_os_disk=None, ephemeral_os_disk_placement=None, eviction_policy=None, generate_ssh_keys=None, health_probe=None, host_group=None, image=None, instance_count=None, lb_nat_pool_name=None, lb_sku=None, license_type=None, load_balancer=None, location=None, max_batch_instance_percent=None, max_price=None, max_unhealthy_instance_percent=None, max_unhealthy_upgraded_instance_percent=None, network_api_version=None, no_wait=None, nsg=None, orchestration_mode=None, os_disk_caching=None, os_disk_encryption_set=None, os_disk_name=None, os_disk_size_gb=None, os_type=None, patch_mode=None, pause_time_between_batches=None, plan_name=None, plan_product=None, plan_promotion_code=None, plan_publisher=None, platform_fault_domain_count=None, ppg=None, prioritize_unhealthy_instances=None, priority=None, public_ip_address=None, public_ip_address_allocation=None, public_ip_address_dns_name=None, public_ip_per_vm=None, role=None, scale_in_policy=None, scope=None, secrets=None, single_placement_group=None, specialized=None, spot_restore_timeout=None, ssh_dest_key_path=None, ssh_key_values=None, storage_container_name=None, storage_sku=None, subnet=None, subnet_address_prefix=None, tags=None, terminate_notification_time=None, ultra_ssd_enabled=None, upgrade_policy_mode=None, use_unmanaged_disk=None, user_data=None, validate=None, vm_domain_name=None, vm_sku=None, vnet_address_prefix=None, vnet_name=None, zones=None):
    '''
    Create an Azure Virtual Machine Scale Set.

    Required Parameters:
    - name -- Name of the virtual machine scale set.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - accelerated_networking -- enable accelerated networking. Unless specified, CLI will enable it based on machine image and size
    - admin_password -- Password for the VM if authentication type is 'Password'.
    - admin_username -- Username for the VM. Default value is current username of OS. If the default value is system reserved, then default value will be set to azureuser. Please refer to https://docs.microsoft.com/rest/api/compute/virtualmachines/createorupdate#osprofile to get a full list of reserved values.
    - app_gateway -- Name to use when creating a new application gateway (default) or referencing an existing one. Can also reference an existing application gateway by ID or specify "" for none.
    - app_gateway_capacity -- The number of instances to use when creating a new application gateway.
    - app_gateway_sku -- SKU when creating a new application gateway.
    - app_gateway_subnet_address_prefix -- The subnet IP address prefix to use when creating a new application gateway in CIDR format.
    - asgs -- Space-separated list of existing application security groups to associate with the VM.
    - assign_identity -- accept system or user assigned identities separated by spaces. Use '[system]' to refer system assigned identity, or a resource id to refer user assigned identity. Check out help for more examples
    - authentication_type -- Type of authentication to use with the VM. Defaults to password for Windows and SSH public key for Linux. "all" enables both ssh and password authentication. 
    - automatic_repairs_grace_period -- The amount of time (in minutes, between 30 and 90) for which automatic repairs are suspended due to a state change on VM.
    - backend_pool_name -- Name to use for the backend pool when creating a new load balancer or application gateway.
    - backend_port -- When creating a new load balancer, backend port to open with NAT rules (Defaults to 22 on Linux and 3389 on Windows). When creating an application gateway, the backend port to use for the backend HTTP settings.
    - capacity_reservation_group -- The ID or name of the capacity reservation group that is used to allocate. Pass in "None" to disassociate the capacity reservation group. Please note that if you want to delete a VM/VMSS that has been associated with capacity reservation group, you need to disassociate the capacity reservation group first.
    - computer_name_prefix -- Computer name prefix for all of the virtual machines in the scale set. Computer name prefixes must be 1 to 15 characters long
    - custom_data -- Custom init script file or text (cloud-init, cloud-config, etc..)
    - data_disk_caching -- storage caching type for data disk(s), including 'None', 'ReadOnly', 'ReadWrite', etc. Use a singular value to apply on all disks, or use `<lun>=<vaule1> <lun>=<value2>` to configure individual disk
    - data_disk_encryption_sets -- Names or IDs (space delimited) of disk encryption sets for data disks.
    - data_disk_iops -- Specify the Read-Write IOPS (space delimited) for the managed disk. Should be used only when StorageAccountType is UltraSSD_LRS. If not specified, a default value would be assigned based on diskSizeGB.
    - data_disk_mbps -- Specify the bandwidth in MB per second (space delimited) for the managed disk. Should be used only when StorageAccountType is UltraSSD_LRS. If not specified, a default value would be assigned based on diskSizeGB.
    - data_disk_sizes_gb -- space-separated empty managed data disk sizes in GB to create
    - disable_overprovision -- Overprovision option (see https://azure.microsoft.com/documentation/articles/virtual-machine-scale-sets-overview/ for details).
    - dns_servers -- space-separated IP addresses of DNS servers, e.g. 10.0.0.5 10.0.0.6
    - edge_zone -- The name of edge zone.
    - enable_agent -- Indicate whether virtual machine agent should be provisioned on the virtual machine. When this property is not specified, default behavior is to set it to true. This will ensure that VM Agent is installed on the VM so that extensions can be added to the VM later
    - enable_auto_update -- Indicate whether Automatic Updates is enabled for the Windows virtual machine
    - enable_cross_zone_upgrade -- Set this Boolean property will allow VMSS to ignore AZ boundaries when constructing upgrade batches, and only consider Update Domain and maxBatchInstancePercent to determine the batch size
    - enable_spot_restore -- Enable the Spot-Try-Restore feature where evicted VMSS SPOT instances will be tried to be restored opportunistically based on capacity availability and pricing constraints
    - encryption_at_host -- Enable Host Encryption for the VM or VMSS. This will enable the encryption for all the disks including Resource/Temp disk at host itself.
    - ephemeral_os_disk -- Allows you to create an OS disk directly on the host node, providing local disk performance and faster VM/VMSS reimage time.
    - ephemeral_os_disk_placement -- Only applicable when used with `--ephemeral-os-disk`. Allows you to choose the Ephemeral OS disk provisioning location.
    - eviction_policy -- The eviction policy for virtual machines in a Spot priority scale set. Default eviction policy is Deallocate for a Spot priority scale set
    - generate_ssh_keys -- Generate SSH public and private key files if missing. The keys will be stored in the ~/.ssh directory
    - health_probe -- Probe name from the existing load balancer, mainly used for rolling upgrade or automatic repairs
    - host_group -- Name or ID of dedicated host group that the virtual machine scale set resides in
    - image -- None
    - instance_count -- Number of VMs in the scale set.
    - lb_nat_pool_name -- Name to use for the NAT pool when creating a new load balancer.
    - lb_sku -- Sku of the Load Balancer to create. Default to 'Standard' when single placement group is turned off; otherwise, default to 'Basic'. The public IP is supported to be created on edge zone only when it is 'Standard'
    - license_type -- Specifies that the Windows image or disk was licensed on-premises. To enable Azure Hybrid Benefit for Windows Server, use 'Windows_Server'. To enable Multitenant Hosting Rights for Windows 10, use 'Windows_Client'. For more information see the Azure Windows VM online docs.
    - load_balancer -- Name to use when creating a new load balancer (default) or referencing an existing one. Can also reference an existing load balancer by ID or specify "" for none.
    - location -- Location in which to create VM and related resources. If default location is not configured, will default to the resource group's location
    - max_batch_instance_percent -- The maximum percent of total virtual machine instances that will be upgraded simultaneously by the rolling upgrade in one batch. Default: 20%
    - max_price -- The maximum price (in US Dollars) you are willing to pay for a Spot VM/VMSS. -1 indicates that the Spot VM/VMSS should not be evicted for price reasons
    - max_unhealthy_instance_percent -- The maximum percentage of the total virtual machine instances in the scale set that can be simultaneously unhealthy. Default: 20%
    - max_unhealthy_upgraded_instance_percent -- The maximum percentage of upgraded virtual machine instances that can be found to be in an unhealthy state. Default: 20%
    - network_api_version -- Specify the Microsoft.Network API version used when creating networking resources in the Network Interface Configurations for Virtual Machine Scale Set with orchestration mode 'Flexible'. Default value is 2020-11-01.
    - no_wait -- Do not wait for the long-running operation to finish.
    - nsg -- Name or ID of an existing Network Security Group.
    - orchestration_mode -- Choose how virtual machines are managed by the scale set. In Uniform mode, you define a virtual machine model and Azure will generate identical instances based on that model. In Flexible mode, you manually create and add a virtual machine of any configuration to the scale set or generate identical instances based on virtual machine model defined for the scale set.
    - os_disk_caching -- Storage caching type for the VM OS disk. Default: ReadWrite
    - os_disk_encryption_set -- Name or ID of disk encryption set for OS disk.
    - os_disk_name -- The name of the new VM OS disk.
    - os_disk_size_gb -- OS disk size in GB to create.
    - os_type -- Type of OS installed on a custom VHD. Do not use when specifying an URN or URN alias.
    - patch_mode -- Mode of in-guest patching to IaaS virtual machine. Allowed values for Windows VM: AutomaticByOS, AutomaticByPlatform, Manual. Allowed values for Linux VM: AutomaticByPlatform, ImageDefault. Manual - You control the application of patches to a virtual machine. You do this by applying patches manually inside the VM. In this mode, automatic updates are disabled; the paramater --enable-auto-update must be false. AutomaticByOS - The virtual machine will automatically be updated by the OS. The parameter --enable-auto-update must be true. AutomaticByPlatform - the virtual machine will automatically updated by the OS. ImageDefault - The virtual machine's default patching configuration is used. The parameter --enable-agent and --enable-auto-update must be true
    - pause_time_between_batches -- The wait time between completing the update for all virtual machines in one batch and starting the next batch. Default: 0 seconds
    - plan_name -- plan name
    - plan_product -- plan product
    - plan_promotion_code -- plan promotion code
    - plan_publisher -- plan publisher
    - platform_fault_domain_count -- Fault Domain count for each placement group in the availability zone
    - ppg -- The name or ID of the proximity placement group the VMSS should be associated with.
    - prioritize_unhealthy_instances -- Set this Boolean property will lead to all unhealthy instances in a scale set getting upgraded before any healthy instances
    - priority -- Priority. Use 'Spot' to run short-lived workloads in a cost-effective way. 'Low' enum will be deprecated in the future. Please use 'Spot' to deploy Azure spot VM and/or VMSS. Default to Regular.
    - public_ip_address -- Name of the public IP address when creating one (default) or referencing an existing one. Can also reference an existing public IP by ID or specify "" for None ('""' in Azure CLI using PowerShell or --% operator).
    - public_ip_address_allocation -- None
    - public_ip_address_dns_name -- Globally unique DNS name for a newly created public IP.
    - public_ip_per_vm -- Each VM instance will have a public ip. For security, you can use '--nsg' to apply appropriate rules
    - role -- Role name or id the system assigned identity will have
    - scale_in_policy -- Specify the scale-in policy (space delimited) that decides which virtual machines are chosen for removal when a Virtual Machine Scale Set is scaled-in.
    - scope -- Scope that the system assigned identity can access
    - secrets -- One or many Key Vault secrets as JSON strings or files via `@{path}` containing `[{ "sourceVault": { "id": "value" }, "vaultCertificates": [{ "certificateUrl": "value", "certificateStore": "cert store name (only on windows)"}] }]`
    - single_placement_group -- Limit the scale set to a single placement group. See https://docs.microsoft.com/azure/virtual-machine-scale-sets/virtual-machine-scale-sets-placement-groups for details.
    - specialized -- Indicate whether the source image is specialized.
    - spot_restore_timeout -- Timeout value expressed as an ISO 8601 time duration after which the platform will not try to restore the VMSS SPOT instances
    - ssh_dest_key_path -- Destination file path on the VM for the SSH key. If the file already exists, the specified key(s) are appended to the file. Destination path for SSH public keys is currently limited to its default value "/home/username/.ssh/authorized_keys" due to a known issue in Linux provisioning agent.
    - ssh_key_values -- None
    - storage_container_name -- Only applicable when used with `--use-unmanaged-disk`. Name of the storage container for the VM OS disk. Default: vhds
    - storage_sku -- The SKU of the storage account with which to persist VM. Use a singular sku that would be applied across all disks, or specify individual disks. Usage: [--storage-sku SKU | --storage-sku ID=SKU ID=SKU ID=SKU...], where each ID is "os" or a 0-indexed lun. Allowed values: Standard_LRS, Premium_LRS, StandardSSD_LRS, UltraSSD_LRS, Premium_ZRS, StandardSSD_ZRS.
    - subnet -- The name of the subnet when creating a new VNet or referencing an existing one. Can also reference an existing subnet by ID. If both vnet-name and subnet are omitted, an appropriate VNet and subnet will be selected automatically, or a new one will be created.
    - subnet_address_prefix -- The subnet IP address prefix to use when creating a new VNet in CIDR format.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - terminate_notification_time -- Length of time (in minutes, between 5 and 15) a notification to be sent to the VM on the instance metadata server till the VM gets deleted
    - ultra_ssd_enabled -- Enables or disables the capability to have 1 or more managed data disks with UltraSSD_LRS storage account
    - upgrade_policy_mode -- None
    - use_unmanaged_disk -- Do not use managed disk to persist VM
    - user_data -- UserData for the virtual machines in the scale set. It can be passed in as file or string.
    - validate -- Generate and validate the ARM template without creating any resources.
    - vm_domain_name -- domain name of VM instances, once configured, the FQDN is `vm<vm-index>.<vm-domain-name>.<..rest..>`
    - vm_sku -- Size of VMs in the scale set. Default to "Standard_DS1_v2". See https://azure.microsoft.com/pricing/details/virtual-machines/ for size info.
    - vnet_address_prefix -- The IP address prefix to use when creating a new VNet in CIDR format.
    - vnet_name -- Name of the virtual network when creating a new one or referencing an existing one.
    - zones -- Space-separated list of availability zones into which to provision the resource.
    '''
    return _call_az("az vmss create", locals())


def deallocate(name, resource_group, instance_ids=None, no_wait=None):
    '''
    Deallocate VMs within a VMSS.

    Required Parameters:
    - name -- Scale set name. You can configure the default using `az configure --defaults vmss=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - instance_ids -- Space-separated list of IDs (ex: 1 2 3 ...) or * for all instances. If not provided, the action will be applied on the scaleset itself
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az vmss deallocate", locals())


def delete(name, resource_group, force_deletion=None, no_wait=None):
    '''
    

    Required Parameters:
    - name -- Scale set name. You can configure the default using `az configure --defaults vmss=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - force_deletion -- Optional parameter to force delete a VM scale set. (Feature in Preview).
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az vmss delete", locals())


def delete_instances(instance_ids, name, resource_group, no_wait=None):
    '''
    Delete VMs within a VMSS.

    Required Parameters:
    - instance_ids -- Space-separated list of IDs (ex: 1 2 3 ...) or * for all instances.
    - name -- Scale set name. You can configure the default using `az configure --defaults vmss=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az vmss delete-instances", locals())


def get_instance_view(name, resource_group, instance_id=None):
    '''
    View an instance of a VMSS.

    Required Parameters:
    - name -- Scale set name. You can configure the default using `az configure --defaults vmss=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - instance_id -- None
    '''
    return _call_az("az vmss get-instance-view", locals())


def list(resource_group=None):
    '''
    List VMSS.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az vmss list", locals())


def list_instances(name, resource_group, expand=None, filter=None, select=None):
    '''
    Get a list of all virtual machines in a VM scale sets.

    Required Parameters:
    - name -- Scale set name. You can configure the default using `az configure --defaults vmss=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - expand -- The expand expression to apply to the operation. Allowed values are 'instanceView'.
    - filter -- The filter to apply to the operation. Allowed values are 'startswith(instanceView/statuses/code, 'PowerState') eq true', 'properties/latestModelApplied eq true', 'properties/latestModelApplied eq false'.
    - select -- The list parameters. Allowed values are 'instanceView', 'instanceView/statuses'.
    '''
    return _call_az("az vmss list-instances", locals())


def list_instance_connection_info(name, resource_group):
    '''
    Get the IP address and port number used to connect to individual VM instances within a set.

    Required Parameters:
    - name -- Scale set name. You can configure the default using `az configure --defaults vmss=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az vmss list-instance-connection-info", locals())


def list_instance_public_ips(name, resource_group):
    '''
    List public IP addresses of VM instances within a set.

    Required Parameters:
    - name -- Scale set name. You can configure the default using `az configure --defaults vmss=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az vmss list-instance-public-ips", locals())


def list_skus(name, resource_group):
    '''
    

    Required Parameters:
    - name -- Scale set name. You can configure the default using `az configure --defaults vmss=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az vmss list-skus", locals())


def reimage(name, resource_group, instance_id=None, no_wait=None):
    '''
    Reimage VMs within a VMSS.

    Required Parameters:
    - name -- Scale set name. You can configure the default using `az configure --defaults vmss=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - instance_id -- None
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az vmss reimage", locals())


def perform_maintenance(name, resource_group, vm_instance_i_ds=None):
    '''
    

    Required Parameters:
    - name -- Scale set name. You can configure the default using `az configure --defaults vmss=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - vm_instance_i_ds -- A list of virtual machine instance IDs from the VM scale set.
    '''
    return _call_az("az vmss perform-maintenance", locals())


def restart(name, resource_group, instance_ids=None, no_wait=None):
    '''
    Restart VMs within a VMSS.

    Required Parameters:
    - name -- Scale set name. You can configure the default using `az configure --defaults vmss=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - instance_ids -- Space-separated list of IDs (ex: 1 2 3 ...) or * for all instances. If not provided, the action will be applied on the scaleset itself
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az vmss restart", locals())


def scale(name, new_capacity, resource_group, no_wait=None):
    '''
    Change the number of VMs within a VMSS.

    Required Parameters:
    - name -- Scale set name. You can configure the default using `az configure --defaults vmss=<name>`
    - new_capacity -- None
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az vmss scale", locals())


def show(name, resource_group, include_user_data=None, instance_id=None):
    '''
    Get details on VMs within a VMSS.

    Required Parameters:
    - name -- Scale set name. You can configure the default using `az configure --defaults vmss=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - include_user_data -- Include the user data properties in the query result.
    - instance_id -- None
    '''
    return _call_az("az vmss show", locals())


def simulate_eviction(instance_id, name, resource_group):
    '''
    Simulate the eviction of a Spot virtual machine in a VM scale set.

    Required Parameters:
    - instance_id -- The instance ID of the virtual machine.
    - name -- Scale set name. You can configure the default using `az configure --defaults vmss=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az vmss simulate-eviction", locals())


def start(name, resource_group, instance_ids=None, no_wait=None):
    '''
    Start VMs within a VMSS.

    Required Parameters:
    - name -- Scale set name. You can configure the default using `az configure --defaults vmss=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - instance_ids -- Space-separated list of IDs (ex: 1 2 3 ...) or * for all instances. If not provided, the action will be applied on the scaleset itself
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az vmss start", locals())


def stop(name, resource_group, instance_ids=None, no_wait=None, skip_shutdown=None):
    '''
    Power off (stop) VMs within a VMSS.

    Required Parameters:
    - name -- Scale set name. You can configure the default using `az configure --defaults vmss=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - instance_ids -- Space-separated list of IDs (ex: 1 2 3 ...) or * for all instances. If not provided, the action will be applied on the scaleset itself
    - no_wait -- Do not wait for the long-running operation to finish.
    - skip_shutdown -- Skip shutdown and power-off immediately.
    '''
    return _call_az("az vmss stop", locals())


def update(name, resource_group, add=None, automatic_repairs_grace_period=None, capacity_reservation_group=None, enable_automatic_repairs=None, enable_cross_zone_upgrade=None, enable_spot_restore=None, enable_terminate_notification=None, ephemeral_os_disk_placement=None, force_string=None, instance_id=None, license_type=None, max_batch_instance_percent=None, max_price=None, max_unhealthy_instance_percent=None, max_unhealthy_upgraded_instance_percent=None, no_wait=None, pause_time_between_batches=None, ppg=None, prioritize_unhealthy_instances=None, priority=None, protect_from_scale_in=None, protect_from_scale_set_actions=None, remove=None, scale_in_policy=None, set=None, spot_restore_timeout=None, terminate_notification_time=None, ultra_ssd_enabled=None, user_data=None, vm_sku=None):
    '''
    Update a VMSS. Run 'az vmss update-instances' command to roll out the changes to VMs if you have not configured upgrade policy.

    Required Parameters:
    - name -- Scale set name. You can configure the default using `az configure --defaults vmss=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - automatic_repairs_grace_period -- The amount of time (in minutes, between 30 and 90) for which automatic repairs are suspended due to a state change on VM.
    - capacity_reservation_group -- The ID or name of the capacity reservation group that is used to allocate. Pass in "None" to disassociate the capacity reservation group. Please note that if you want to delete a VM/VMSS that has been associated with capacity reservation group, you need to disassociate the capacity reservation group first.
    - enable_automatic_repairs -- Enable automatic repairs
    - enable_cross_zone_upgrade -- Set this Boolean property will allow VMSS to ignore AZ boundaries when constructing upgrade batches, and only consider Update Domain and maxBatchInstancePercent to determine the batch size
    - enable_spot_restore -- Enable the Spot-Try-Restore feature where evicted VMSS SPOT instances will be tried to be restored opportunistically based on capacity availability and pricing constraints
    - enable_terminate_notification -- Enable terminate notification
    - ephemeral_os_disk_placement -- Only applicable when used with `--vm-sku`. Allows you to choose the Ephemeral OS disk provisioning location.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - instance_id -- Update the VM instance with this ID. If missing, Update the VMSS.
    - license_type -- Specifies that the Windows image or disk was licensed on-premises. To enable Azure Hybrid Benefit for Windows Server, use 'Windows_Server'. To enable Multitenant Hosting Rights for Windows 10, use 'Windows_Client'. For more information see the Azure Windows VM online docs.
    - max_batch_instance_percent -- The maximum percent of total virtual machine instances that will be upgraded simultaneously by the rolling upgrade in one batch. Default: 20%
    - max_price -- The maximum price (in US Dollars) you are willing to pay for a Spot VM/VMSS. -1 indicates that the Spot VM/VMSS should not be evicted for price reasons
    - max_unhealthy_instance_percent -- The maximum percentage of the total virtual machine instances in the scale set that can be simultaneously unhealthy. Default: 20%
    - max_unhealthy_upgraded_instance_percent -- The maximum percentage of upgraded virtual machine instances that can be found to be in an unhealthy state. Default: 20%
    - no_wait -- Do not wait for the long-running operation to finish.
    - pause_time_between_batches -- The wait time between completing the update for all virtual machines in one batch and starting the next batch. Default: 0 seconds
    - ppg -- The name or ID of the proximity placement group the VMSS should be associated with.
    - prioritize_unhealthy_instances -- Set this Boolean property will lead to all unhealthy instances in a scale set getting upgraded before any healthy instances
    - priority -- Priority. Use 'Spot' to run short-lived workloads in a cost-effective way. 'Low' enum will be deprecated in the future. Please use 'Spot' to deploy Azure spot VM and/or VMSS. Default to Regular.
    - protect_from_scale_in -- Protect the VM instance from scale-in operations.
    - protect_from_scale_set_actions -- Protect the VM instance from scale set actions (including scale-in).
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - scale_in_policy -- Specify the scale-in policy (space delimited) that decides which virtual machines are chosen for removal when a Virtual Machine Scale Set is scaled-in.
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - spot_restore_timeout -- Timeout value expressed as an ISO 8601 time duration after which the platform will not try to restore the VMSS SPOT instances
    - terminate_notification_time -- Length of time (in minutes, between 5 and 15) a notification to be sent to the VM on the instance metadata server till the VM gets deleted
    - ultra_ssd_enabled -- Enables or disables the capability to have 1 or more managed data disks with UltraSSD_LRS storage account
    - user_data -- UserData for the virtual machines in the scale set. It can be passed in as file or string. If empty string is passed in, the existing value will be deleted.
    - vm_sku -- The new size of the virtual machine instances in the scale set. Default to "Standard_DS1_v2". See https://azure.microsoft.com/pricing/details/virtual-machines/ for size info.
    '''
    return _call_az("az vmss update", locals())


def update_instances(instance_ids, name, resource_group, no_wait=None):
    '''
    Upgrade VMs within a VMSS.

    Required Parameters:
    - instance_ids -- Space-separated list of IDs (ex: 1 2 3 ...) or * for all instances.
    - name -- Scale set name. You can configure the default using `az configure --defaults vmss=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az vmss update-instances", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, instance_id=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of a scale set is met.

    Required Parameters:
    - name -- Scale set name. You can configure the default using `az configure --defaults vmss=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - instance_id -- Wait on the VM instance with this ID. If missing, Wait on the VMSS.
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az vmss wait", locals())


def get_os_upgrade_history(name, resource_group):
    '''
    

    Required Parameters:
    - name -- Scale set name. You can configure the default using `az configure --defaults vmss=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az vmss get-os-upgrade-history", locals())


def set_orchestration_service_state(action, name, resource_group, service_name, no_wait=None):
    '''
    Change ServiceState property for a given service within a VMSS.

    Required Parameters:
    - action -- The action to be performed.
    - name -- Scale set name. You can configure the default using `az configure --defaults vmss=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the orchestration service.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az vmss set-orchestration-service-state", locals())




'''
Manage network profiles.
'''
from ... pyaz_utils import _call_az

def delete(name, resource_group, yes=None):
    '''
    Delete a network profile.

    Required Parameters:
    - name -- The network profile name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az network profile delete", locals())


def list(resource_group=None):
    '''
    List network profiles.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network profile list", locals())


def show(name, resource_group, expand=None):
    '''
    Get the details of a network profile.

    Required Parameters:
    - name -- The network profile name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - expand -- Expands referenced resources.
    '''
    return _call_az("az network profile show", locals())




from .... pyaz_utils import _call_az

def create(name, policy_name, resource_group, service, service_resources, description=None):
    '''
    Create a service endpoint policy definition.

    Required Parameters:
    - name -- Name of the service endpoint policy definition
    - policy_name -- Name of the service endpoint policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service -- Service name the policy definition applies to.
    - service_resources -- Space-separated list of service resources the definition applies to.

    Optional Parameters:
    - description -- Description of the policy definition.
    '''
    return _call_az("az network service-endpoint policy-definition create", locals())


def delete(name, policy_name, resource_group):
    '''
    Delete a service endpoint policy definition.

    Required Parameters:
    - name -- Name of the service endpoint policy definition
    - policy_name -- Name of the service endpoint policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network service-endpoint policy-definition delete", locals())


def list(policy_name, resource_group):
    '''
    List service endpoint policy definitions.

    Required Parameters:
    - policy_name -- Name of the service endpoint policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network service-endpoint policy-definition list", locals())


def show(name, policy_name, resource_group):
    '''
    Get the details of a service endpoint policy definition.

    Required Parameters:
    - name -- Name of the service endpoint policy definition
    - policy_name -- Name of the service endpoint policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network service-endpoint policy-definition show", locals())


def update(name, policy_name, resource_group, add=None, description=None, force_string=None, remove=None, service=None, service_resources=None, set=None):
    '''
    Update a service endpoint policy definition.

    Required Parameters:
    - name -- Name of the service endpoint policy definition
    - policy_name -- Name of the service endpoint policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - description -- Description of the policy definition.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - service -- Service name the policy definition applies to.
    - service_resources -- Space-separated list of service resources the definition applies to.
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az network service-endpoint policy-definition update", locals())




'''
Manage Azure NetApp Files (ANF) Vault Resources.
'''
from ... pyaz_utils import _call_az

def list(account_name, resource_group):
    '''
    List the ANF vaults for NetApp Account.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az netappfiles vault list", locals())




from ... pyaz_utils import _call_az

def init_recovery(sd_exchange_key, hsm_name=None, id=None):
    '''
    Retrieve the exchange key of the HSM.

    Required Parameters:
    - sd_exchange_key -- Local file path to store the exported key.

    Optional Parameters:
    - hsm_name -- Name of the HSM. Can be omitted if --id is specified.
    - id -- Full URI of the HSM.
    '''
    return _call_az("az keyvault security-domain init-recovery", locals())


def upload(sd_exchange_key, sd_file, sd_wrapping_keys, hsm_name=None, id=None, no_wait=None, passwords=None):
    '''
    Start to restore the HSM.

    Required Parameters:
    - sd_exchange_key -- The exchange key for security domain.
    - sd_file -- This file contains security domain encrypted using SD Exchange file downloaded in security-domain init-recovery command.
    - sd_wrapping_keys -- Space-separated file paths to PEM files containing private keys.

    Optional Parameters:
    - hsm_name -- Name of the HSM. Can be omitted if --id is specified.
    - id -- Full URI of the HSM.
    - no_wait -- Do not wait for the long-running operation to finish.
    - passwords -- Space-separated password list for --sd-wrapping-keys. CLI will match them in order. Can be omitted if your keys are without password protection.
    '''
    return _call_az("az keyvault security-domain upload", locals())


def download(sd_quorum, sd_wrapping_keys, security_domain_file, hsm_name=None, id=None, no_wait=None):
    '''
    Download the security domain file from the HSM.

    Required Parameters:
    - sd_quorum -- The minimum number of shares required to decrypt the security domain for recovery.
    - sd_wrapping_keys -- Space-separated file paths to PEM files containing public keys.
    - security_domain_file -- Path to a file where the JSON blob returned by this command is stored.

    Optional Parameters:
    - hsm_name -- Name of the HSM. Can be omitted if --id is specified.
    - id -- Full URI of the HSM.
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az keyvault security-domain download", locals())


def wait(hsm_name=None, id=None, target_operation=None):
    '''
    Place the CLI in a waiting state until HSM security domain operation is finished.

    Optional Parameters:
    - hsm_name -- Name of the HSM. Can be omitted if --id is specified.
    - id -- Full URI of the HSM.
    - target_operation -- Target operation that needs waiting.
    '''
    return _call_az("az keyvault security-domain wait", locals())




'''
Manage resource groups and template deployments.
'''
from .. pyaz_utils import _call_az
from . import deployment, lock


def delete(name, force_deletion_types=None, no_wait=None, yes=None):
    '''
    Delete a resource group.

    Required Parameters:
    - name -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - force_deletion_types -- The resource types you want to force delete. Currently, only the following is supported: forceDeletionTypes=Microsoft.Compute/virtualMachines,Microsoft.Compute/virtualMachineScaleSets.
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az group delete", locals())


def show(name):
    '''
    

    Required Parameters:
    - name -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az group show", locals())


def exists(name):
    '''
    Check if a resource group exists.

    Required Parameters:
    - name -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az group exists", locals())


def list(tag=None):
    '''
    List resource groups.

    Optional Parameters:
    - tag -- a single tag in 'key[=value]' format. Use '' to clear existing tags.
    '''
    return _call_az("az group list", locals())


def create(location, name, managed_by=None, tags=None):
    '''
    Create a new resource group.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- name of the new resource group

    Optional Parameters:
    - managed_by -- The ID of the resource that manages this resource group.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az group create", locals())


def export(name, include_comments=None, include_parameter_default_value=None, resource_ids=None, skip_all_params=None, skip_resource_name_params=None):
    '''
    

    Required Parameters:
    - name -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - include_comments -- export template with comments.
    - include_parameter_default_value -- export template parameter with default value.
    - resource_ids -- space-separated resource ids to filter the export by. To export all resources, do not specify this argument or supply "*".
    - skip_all_params -- export template parameter and skip all parameterization.
    - skip_resource_name_params -- export template and skip resource name parameterization.
    '''
    return _call_az("az group export", locals())


def update(name, add=None, force_string=None, remove=None, set=None, tags=None):
    '''
    Update a resource group.

    Required Parameters:
    - name -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az group update", locals())


def wait(name, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the resource group is met.

    Required Parameters:
    - name -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az group wait", locals())




from .... pyaz_utils import _call_az

def show(name, resource_group, scope_name):
    '''
    Show a private link resource of a private link scope resource.

    Required Parameters:
    - name -- Name of the private link resource.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - scope_name -- Name of the Azure Monitor Private Link Scope.
    '''
    return _call_az("az monitor private-link-scope private-link-resource show", locals())


def list(resource_group, scope_name):
    '''
    List all private link resources of a private link scope resource.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - scope_name -- Name of the Azure Monitor Private Link Scope.
    '''
    return _call_az("az monitor private-link-scope private-link-resource list", locals())




'''
Manage Azure Cosmos DB collections.
'''
from ... pyaz_utils import _call_az

def show(collection_name, db_name, key=None, name=None, resource_group_name=None, url_connection=None):
    '''
    

    Required Parameters:
    - collection_name -- Collection Name
    - db_name -- Database Name

    Optional Parameters:
    - key -- Cosmos DB account key. Must be used in conjunction with cosmosdb account name or url-connection.
    - name -- Cosmos DB account name. Must be used in conjunction with either name of the resource group or cosmosdb account key.
    - resource_group_name -- name of the resource group. Must be used in conjunction with cosmosdb account name.
    - url_connection -- Cosmos DB account url connection. Must be used in conjunction with cosmosdb account key.
    '''
    return _call_az("az cosmosdb collection show", locals())


def list(db_name, key=None, name=None, resource_group_name=None, url_connection=None):
    '''
    

    Required Parameters:
    - db_name -- Database Name

    Optional Parameters:
    - key -- Cosmos DB account key. Must be used in conjunction with cosmosdb account name or url-connection.
    - name -- Cosmos DB account name. Must be used in conjunction with either name of the resource group or cosmosdb account key.
    - resource_group_name -- name of the resource group. Must be used in conjunction with cosmosdb account name.
    - url_connection -- Cosmos DB account url connection. Must be used in conjunction with cosmosdb account key.
    '''
    return _call_az("az cosmosdb collection list", locals())


def exists(collection_name, db_name, key=None, name=None, resource_group_name=None, url_connection=None):
    '''
    

    Required Parameters:
    - collection_name -- Collection Name
    - db_name -- Database Name

    Optional Parameters:
    - key -- Cosmos DB account key. Must be used in conjunction with cosmosdb account name or url-connection.
    - name -- Cosmos DB account name. Must be used in conjunction with either name of the resource group or cosmosdb account key.
    - resource_group_name -- name of the resource group. Must be used in conjunction with cosmosdb account name.
    - url_connection -- Cosmos DB account url connection. Must be used in conjunction with cosmosdb account key.
    '''
    return _call_az("az cosmosdb collection exists", locals())


def create(collection_name, db_name, default_ttl=None, indexing_policy=None, key=None, name=None, partition_key_path=None, resource_group_name=None, throughput=None, url_connection=None):
    '''
    

    Required Parameters:
    - collection_name -- Collection Name
    - db_name -- Database Name

    Optional Parameters:
    - default_ttl -- Default TTL. Provide 0 to disable.
    - indexing_policy -- Indexing Policy, you can enter it as a string or as a file, e.g., --indexing-policy @policy-file.json)
    - key -- Cosmos DB account key. Must be used in conjunction with cosmosdb account name or url-connection.
    - name -- Cosmos DB account name. Must be used in conjunction with either name of the resource group or cosmosdb account key.
    - partition_key_path -- Partition Key Path, e.g., '/properties/name'
    - resource_group_name -- name of the resource group. Must be used in conjunction with cosmosdb account name.
    - throughput -- Offer Throughput (RU/s)
    - url_connection -- Cosmos DB account url connection. Must be used in conjunction with cosmosdb account key.
    '''
    return _call_az("az cosmosdb collection create", locals())


def delete(collection_name, db_name, key=None, name=None, resource_group_name=None, url_connection=None, yes=None):
    '''
    

    Required Parameters:
    - collection_name -- Collection Name
    - db_name -- Database Name

    Optional Parameters:
    - key -- Cosmos DB account key. Must be used in conjunction with cosmosdb account name or url-connection.
    - name -- Cosmos DB account name. Must be used in conjunction with either name of the resource group or cosmosdb account key.
    - resource_group_name -- name of the resource group. Must be used in conjunction with cosmosdb account name.
    - url_connection -- Cosmos DB account url connection. Must be used in conjunction with cosmosdb account key.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az cosmosdb collection delete", locals())


def update(collection_name, db_name, default_ttl=None, indexing_policy=None, key=None, name=None, resource_group_name=None, throughput=None, url_connection=None):
    '''
    

    Required Parameters:
    - collection_name -- Collection Name
    - db_name -- Database Name

    Optional Parameters:
    - default_ttl -- Default TTL. Provide 0 to disable.
    - indexing_policy -- Indexing Policy, you can enter it as a string or as a file, e.g., --indexing-policy @policy-file.json)
    - key -- Cosmos DB account key. Must be used in conjunction with cosmosdb account name or url-connection.
    - name -- Cosmos DB account name. Must be used in conjunction with either name of the resource group or cosmosdb account key.
    - resource_group_name -- name of the resource group. Must be used in conjunction with cosmosdb account name.
    - throughput -- Offer Throughput (RU/s)
    - url_connection -- Cosmos DB account url connection. Must be used in conjunction with cosmosdb account key.
    '''
    return _call_az("az cosmosdb collection update", locals())




from .... pyaz_utils import _call_az

def create(account, id_provider, trusted_id_provider_name, resource_group=None):
    '''
    

    Required Parameters:
    - account -- Name of the Data Lake Store account.
    - id_provider -- The URL of this trusted identity provider.
    - trusted_id_provider_name -- The name of the trusted identity provider. This is used for differentiation of providers in the account.

    Optional Parameters:
    - resource_group -- If not specified, will attempt to discover the resource group for the specified Data Lake Store account.
    '''
    return _call_az("az dls account trusted-provider create", locals())


def update(account, trusted_id_provider_name, id_provider=None, resource_group=None):
    '''
    

    Required Parameters:
    - account -- Name of the Data Lake Store account.
    - trusted_id_provider_name -- The name of the trusted identity provider. This is used for differentiation of providers in the account.

    Optional Parameters:
    - id_provider -- The URL of this trusted identity provider.
    - resource_group -- If not specified, will attempt to discover the resource group for the specified Data Lake Store account.
    '''
    return _call_az("az dls account trusted-provider update", locals())


def list(account, resource_group=None):
    '''
    

    Required Parameters:
    - account -- Name of the Data Lake Store account.

    Optional Parameters:
    - resource_group -- If not specified, will attempt to discover the resource group for the specified Data Lake Store account.
    '''
    return _call_az("az dls account trusted-provider list", locals())


def show(account, trusted_id_provider_name, resource_group=None):
    '''
    

    Required Parameters:
    - account -- Name of the Data Lake Store account.
    - trusted_id_provider_name -- The name of the trusted identity provider to retrieve.

    Optional Parameters:
    - resource_group -- If not specified, will attempt to discover the resource group for the specified Data Lake Store account.
    '''
    return _call_az("az dls account trusted-provider show", locals())


def delete(account, trusted_id_provider_name, resource_group=None):
    '''
    

    Required Parameters:
    - account -- Name of the Data Lake Store account.
    - trusted_id_provider_name -- The name of the trusted identity provider to delete.

    Optional Parameters:
    - resource_group -- If not specified, will attempt to discover the resource group for the specified Data Lake Store account.
    '''
    return _call_az("az dls account trusted-provider delete", locals())




from ... pyaz_utils import _call_az

def list(assessed_resource_id=None, assessment_name=None):
    '''
    List all security sub assessment results.

    Optional Parameters:
    - assessed_resource_id -- The target resource for this assessment
    - assessment_name -- Name of the assessment resource
    '''
    return _call_az("az security sub-assessment list", locals())


def show(assessment_name, name, assessed_resource_id=None):
    '''
    Shows a security sub assessment.

    Required Parameters:
    - assessment_name -- Name of the assessment resource
    - name -- name of the resource to be fetched

    Optional Parameters:
    - assessed_resource_id -- The target resource for this assessment
    '''
    return _call_az("az security sub-assessment show", locals())




'''
Manage Batch service quotas at the region level.
'''
from .... pyaz_utils import _call_az

def show(location):
    '''
    

    Required Parameters:
    - location -- The region for which to display the Batch service quotas.
    '''
    return _call_az("az batch location quotas show", locals())




'''
View your security contacts.
'''
from ... pyaz_utils import _call_az

def list():
    '''
    List security contact.
    '''
    return _call_az("az security contact list", locals())


def show(name):
    '''
    Shows a security contact.

    Required Parameters:
    - name -- name of the resource to be fetched
    '''
    return _call_az("az security contact show", locals())


def create(email, name, alert_notifications=None, alerts_admins=None, phone=None):
    '''
    Creates a security contact.

    Required Parameters:
    - email -- E-mail of the security contact
    - name -- name of the resource to be fetched

    Optional Parameters:
    - alert_notifications -- Whether to send mail notifications to the security contacts
    - alerts_admins -- Whether to send mail notifications to the subscription administrators
    - phone -- Phone of the security contact
    '''
    return _call_az("az security contact create", locals())


def delete(name):
    '''
    Deletes a security contact.

    Required Parameters:
    - name -- name of the resource to be fetched
    '''
    return _call_az("az security contact delete", locals())




from .... pyaz_utils import _call_az

def start(destination_blob, destination_container, account_key=None, account_name=None, auth_mode=None, connection_string=None, destination_if_match=None, destination_if_modified_since=None, destination_if_none_match=None, destination_if_unmodified_since=None, destination_lease_id=None, metadata=None, sas_token=None, source_account_key=None, source_account_name=None, source_blob=None, source_container=None, source_lease_id=None, source_sas=None, source_snapshot=None, source_uri=None, timeout=None):
    '''
    Copies an incremental copy of a blob asynchronously.

    Required Parameters:
    - destination_blob -- Name of the destination blob. If the exists, it will be overwritten.
    - destination_container -- The container name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - destination_if_match --  An ETag value, or the wildcard character (*). Specify an ETag value for this conditional header to copy the blob only if the specified ETag value matches the ETag value for an existing destination blob. If the ETag for the destination blob does not match the ETag specified for If-Match, the Blob service returns status code 412 (Precondition Failed).
    - destination_if_modified_since -- Commence only if modified since supplied UTC datetime (Y-m-d'T'H:M'Z')
    - destination_if_none_match --  An ETag value, or the wildcard character (*). Specify an ETag value for this conditional header to copy the blob only if the specified ETag value does not match the ETag value for the destination blob. Specify the wildcard character (*) to perform the operation only if the destination blob does not exist. If the specified condition isn't met, the Blob service returns status code 412 (Precondition Failed).
    - destination_if_unmodified_since -- Commence only if unmodified since supplied UTC datetime (Y-m-d'T'H:M'Z')
    - destination_lease_id --  The lease ID specified for this header must match the lease ID of the destination blob. If the request does not include the lease ID or it is not valid, the operation fails with status code 412 (Precondition Failed).
    - metadata -- Metadata in space-separated key=value pairs. This overwrites any existing metadata.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - source_account_key -- The storage account key of the source blob.
    - source_account_name -- The storage account name of the source blob.
    - source_blob -- The blob name for the source storage account.
    - source_container -- The container name for the source storage account.
    - source_lease_id --  Specify this to perform the Copy Blob operation only if the lease ID given matches the active lease ID of the source blob.
    - source_sas -- The shared access signature for the source storage account.
    - source_snapshot -- The blob snapshot for the source storage account.
    - source_uri --  A URL of up to 2 KB in length that specifies an Azure page blob. The value should be URL-encoded as it would appear in a request URI. The copy source must be a snapshot and include a valid SAS token or be public. Example: https://myaccount.blob.core.windows.net/mycontainer/myblob?snapshot=<DateTime>&sastoken
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage blob incremental-copy start", locals())


def cancel(container_name, copy_id, name, account_key=None, account_name=None, auth_mode=None, connection_string=None, lease_id=None, sas_token=None, timeout=None):
    '''
    

    Required Parameters:
    - container_name -- The container name.
    - copy_id --  Copy identifier provided in the copy.id of the original copy_blob operation.
    - name -- The blob name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - lease_id --  Required if the destination blob has an active infinite lease.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage blob incremental-copy cancel", locals())




from .... pyaz_utils import _call_az

def set(account_name, container_name, tags, allow_protected_append_writes_all=None, resource_group=None):
    '''
    Set legal hold tags.

    Required Parameters:
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT.
    - container_name -- The container name.
    - tags -- Space-separated tags. Each tag should be 3 to 23 alphanumeric characters and is normalized to lower case

    Optional Parameters:
    - allow_protected_append_writes_all -- When enabled, new blocks can be written to both Append and Block Blobs while maintaining legal hold protection and compliance. Only new blocks can be added and any existing blocks cannot be modified or deleted.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage container legal-hold set", locals())


def clear(account_name, container_name, tags, allow_protected_append_writes_all=None, resource_group=None):
    '''
    Clear legal hold tags.

    Required Parameters:
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT.
    - container_name -- The container name.
    - tags -- Space-separated tags. Each tag should be 3 to 23 alphanumeric characters and is normalized to lower case

    Optional Parameters:
    - allow_protected_append_writes_all -- When enabled, new blocks can be written to both Append and Block Blobs while maintaining legal hold protection and compliance. Only new blocks can be added and any existing blocks cannot be modified or deleted.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage container legal-hold clear", locals())


def show(account_name, container_name, resource_group=None):
    '''
    Get the legal hold properties of a container.

    Required Parameters:
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT.
    - container_name -- The container name.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage container legal-hold show", locals())




'''
Manage SQL virtual machines.
'''
from ... pyaz_utils import _call_az
from . import group


def update(name, resource_group, add=None, backup_pwd=None, backup_schedule_type=None, backup_system_dbs=None, connectivity_type=None, credential_name=None, day_of_week=None, enable_auto_backup=None, enable_auto_patching=None, enable_encryption=None, enable_key_vault_credential=None, enable_r_services=None, force_string=None, full_backup_duration=None, full_backup_frequency=None, full_backup_start_hour=None, image_sku=None, key_vault=None, license_type=None, log_backup_frequency=None, maintenance_window_duration=None, maintenance_window_start_hour=None, port=None, remove=None, retention_period=None, sa_key=None, set=None, sp_name=None, sp_secret=None, sql_mgmt_type=None, sql_workload_type=None, storage_account=None, tags=None, yes=None):
    '''
    Updates the properties of a SQL virtual machine.

    Required Parameters:
    - name -- Name of the SQL virtual machine.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - backup_pwd -- Password for encryption on backup.
    - backup_schedule_type -- Backup schedule type.
    - backup_system_dbs -- Include system databases on backup.
    - connectivity_type -- SQL Server connectivity option.
    - credential_name -- Credential name
    - day_of_week -- Day of week to apply the patch on.
    - enable_auto_backup -- Enable or disable autobackup on SQL virtual machine. If any backup settings provided, parameter automatically sets to true.
    - enable_auto_patching -- Enable or disable autopatching on SQL virtual machine. If any autopatching settings provided, parameter automatically sets to true.
    - enable_encryption --  Enable encryption for backup on SQL virtual machine.
    - enable_key_vault_credential -- Enable or disable key vault credential setting. If any key vault settings provided, parameter automatically sets to true.
    - enable_r_services -- Enable or disable R services (SQL 2016 onwards).
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - full_backup_duration -- Duration of the time window of a given day during which full backups can take place. 1-23 hours.
    - full_backup_frequency -- Frequency of full backups. In both cases, full backups begin during the next scheduled time window.
    - full_backup_start_hour -- Start time of a given day during which full backups can take place. 0-23 hours.
    - image_sku -- SQL image sku.
    - key_vault -- Azure Key Vault url.
    - license_type -- SQL Server license type.
    - log_backup_frequency -- Frequency of log backups. 5-60 minutes.
    - maintenance_window_duration -- Duration of patching. 30-180 minutes.
    - maintenance_window_start_hour -- Hour of the day when patching is initiated. Local VM time 0-23 hours.
    - port -- SQL Server port.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - retention_period -- Retention period of backup. 1-30 days.
    - sa_key -- Storage account key where backup will be taken to.
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - sp_name -- Service principal name to access key vault.
    - sp_secret -- Service principal name secret to access key vault.
    - sql_mgmt_type -- SQL Server management type. Updates from LightWeight to Full.
    - sql_workload_type -- SQL Server workload type.
    - storage_account -- Storage account url where backup will be taken to.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - yes -- Do not prompt for confirmation. Requires --sql-mgmt-type.
    '''
    return _call_az("az sql vm update", locals())


def show(name, resource_group, expand=None):
    '''
    

    Required Parameters:
    - name -- Name of the SQL virtual machine.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - expand -- Get the SQLIaaSExtension configuration settings. To view all settings, use *. To select only a few, the settings must be space-separted.
    '''
    return _call_az("az sql vm show", locals())


def list(resource_group=None):
    '''
    

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sql vm list", locals())


def add_to_group(name, resource_group, sqlvm_group, operator_acc_pwd=None, service_acc_pwd=None):
    '''
    Adds SQL virtual machine to a SQL virtual machine group.

    Required Parameters:
    - name -- Name of the SQL virtual machine.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - sqlvm_group -- Name or resource ID of the SQL virtual machine group. If only name provided, SQL virtual machine group should be in the same resource group of the SQL virtual machine.

    Optional Parameters:
    - operator_acc_pwd -- Password for the cluster operator account provided in the SQL virtual machine group.
    - service_acc_pwd -- Password for the SQL service account provided in the SQL virtual machine group.
    '''
    return _call_az("az sql vm add-to-group", locals())


def remove_from_group(name, resource_group):
    '''
    Remove SQL virtual machine from its current SQL virtual machine group.

    Required Parameters:
    - name -- Name of the SQL virtual machine.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sql vm remove-from-group", locals())


def delete(name, resource_group, yes=None):
    '''
    

    Required Parameters:
    - name -- Name of the SQL virtual machine.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az sql vm delete", locals())


def create(name, resource_group, backup_pwd=None, backup_schedule_type=None, backup_system_dbs=None, connectivity_type=None, credential_name=None, day_of_week=None, enable_auto_backup=None, enable_auto_patching=None, enable_encryption=None, enable_key_vault_credential=None, enable_r_services=None, full_backup_duration=None, full_backup_frequency=None, full_backup_start_hour=None, image_offer=None, image_sku=None, key_vault=None, license_type=None, location=None, log_backup_frequency=None, maintenance_window_duration=None, maintenance_window_start_hour=None, port=None, retention_period=None, sa_key=None, sp_name=None, sp_secret=None, sql_auth_update_pwd=None, sql_auth_update_username=None, sql_mgmt_type=None, sql_workload_type=None, storage_account=None, tags=None):
    '''
    Creates a SQL virtual machine.

    Required Parameters:
    - name -- Name of the SQL virtual machine.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - backup_pwd -- Password for encryption on backup.
    - backup_schedule_type -- Backup schedule type.
    - backup_system_dbs -- Include system databases on backup.
    - connectivity_type -- SQL Server connectivity option.
    - credential_name -- Credential name
    - day_of_week -- Day of week to apply the patch on.
    - enable_auto_backup -- Enable or disable autobackup on SQL virtual machine. If any backup settings provided, parameter automatically sets to true.
    - enable_auto_patching -- Enable or disable autopatching on SQL virtual machine. If any autopatching settings provided, parameter automatically sets to true.
    - enable_encryption --  Enable encryption for backup on SQL virtual machine.
    - enable_key_vault_credential -- Enable or disable key vault credential setting. If any key vault settings provided, parameter automatically sets to true.
    - enable_r_services -- Enable or disable R services (SQL 2016 onwards).
    - full_backup_duration -- Duration of the time window of a given day during which full backups can take place. 1-23 hours.
    - full_backup_frequency -- Frequency of full backups. In both cases, full backups begin during the next scheduled time window.
    - full_backup_start_hour -- Start time of a given day during which full backups can take place. 0-23 hours.
    - image_offer -- SQL image offer. Examples include SQL2008R2-WS2008, SQL2008-WS2008.
    - image_sku -- SQL image sku.
    - key_vault -- Azure Key Vault url.
    - license_type -- SQL Server license type.
    - location -- Location. If not provided, virtual machine should be in the same region of resource group.You can configure the default location using `az configure --defaults location=<location>`.
    - log_backup_frequency -- Frequency of log backups. 5-60 minutes.
    - maintenance_window_duration -- Duration of patching. 30-180 minutes.
    - maintenance_window_start_hour -- Hour of the day when patching is initiated. Local VM time 0-23 hours.
    - port -- SQL Server port.
    - retention_period -- Retention period of backup. 1-30 days.
    - sa_key -- Storage account key where backup will be taken to.
    - sp_name -- Service principal name to access key vault.
    - sp_secret -- Service principal name secret to access key vault.
    - sql_auth_update_pwd -- SQL Server sysadmin login password.
    - sql_auth_update_username -- SQL Server sysadmin login to create.
    - sql_mgmt_type -- SQL Server management type. If NoAgent selected, please provide --image-sku and --offer-type.
    - sql_workload_type -- SQL Server workload type.
    - storage_account -- Storage account url where backup will be taken to.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az sql vm create", locals())




'''
Manage the Webchat Channel on a bot.
'''
from ... pyaz_utils import _call_az

def show(name, resource_group, with_secrets=None):
    '''
    Get details of the Webchat Channel on a bot

    Required Parameters:
    - name -- The resource name of the bot. Bot name must be between 4 and 42 characters in length. Bot name can only have the following characters -, a - z, A - Z, 0 - 9, and _.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - with_secrets -- Show secrets in response for the channel.
    '''
    return _call_az("az bot webchat show", locals())




'''
Commands to manage jobs.
'''
from ... pyaz_utils import _call_az
from . import file, node


def create(cluster, config_file, experiment, name, resource_group, workspace, afs_mount_path=None, afs_name=None, bfs_mount_path=None, bfs_name=None, nfs=None, nfs_mount_path=None, storage_account_key=None, storage_account_name=None):
    '''
    Create a job.

    Required Parameters:
    - cluster -- Name or ARM ID of the cluster to run the job. You need to provide ARM ID if the cluster belongs to a different workspace.
    - config_file -- A path to a json file containing job create parameters (json representation of azure.mgmt.batchai.models.JobCreateParameters).
    - experiment -- Name of experiment.
    - name -- Name of job.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace -- Name of workspace.

    Optional Parameters:
    - afs_mount_path -- Relative mount path for Azure File Share. The File Share will be available at $AZ_BATCHAI_JOB_MOUNT_ROOT/<relative_mount_path> folder.
    - afs_name -- Name of Azure File Share to mount during the job execution. The File Share will be mounted only on the nodes which are executing the job. Must be used in conjunction with --storage-account-name.  Multiple shares can be mounted using configuration file (see --config-file option).
    - bfs_mount_path -- Relative mount path for Azure Storage Blob Container. The container will be available at $AZ_BATCHAI_JOB_MOUNT_ROOT/<relative_mount_path> folder.
    - bfs_name -- Name of Azure Storage Blob Container to mount during the job execution. The container will be mounted only on the nodes which are executing the job. Must be used in conjunction with --storage-account-name. Multiple containers can be mounted using configuration file (see --config-file option).
    - nfs -- Name or ARM ID of the file server to be mounted during the job execution. You need to provide ARM ID if the file server belongs to a different workspace. You can configure multiple file servers using job's  configuration file.
    - nfs_mount_path -- Relative mount path for NFS. The NFS will be available at $AZ_BATCHAI_JOB_MOUNT_ROOT/<relative_mount_path> folder.
    - storage_account_key -- Storage account key. Required if the storage account belongs to a different subscription. Can be specified using AZURE_BATCHAI_STORAGE_KEY environment variable.
    - storage_account_name -- Storage account name for Azure File Shares and/or Azure Storage Containers to be mounted on each cluster node. Can be specified using AZURE_BATCHAI_STORAGE_ACCOUNT environment variable.
    '''
    return _call_az("az batchai job create", locals())


def delete(experiment, name, resource_group, workspace, no_wait=None, yes=None):
    '''
    Delete a job.

    Required Parameters:
    - experiment -- Name of experiment.
    - name -- Name of job.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace -- Name of workspace.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az batchai job delete", locals())


def terminate(experiment, name, resource_group, workspace, no_wait=None, yes=None):
    '''
    Terminate a job.

    Required Parameters:
    - experiment -- Name of experiment.
    - name -- Name of job.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace -- Name of workspace.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az batchai job terminate", locals())


def show(experiment, name, resource_group, workspace):
    '''
    Show information about a job.

    Required Parameters:
    - experiment -- Name of experiment.
    - name -- Name of job.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace -- Name of workspace.
    '''
    return _call_az("az batchai job show", locals())


def list(experiment, resource_group, workspace):
    '''
    List jobs.

    Required Parameters:
    - experiment -- Name of experiment.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace -- Name of workspace.
    '''
    return _call_az("az batchai job list", locals())


def wait(experiment, name, resource_group, workspace, interval=None):
    '''
    Waits for specified job completion and setups the exit code to the job's exit code.

    Required Parameters:
    - experiment -- Name of experiment.
    - name -- Name of job.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace -- Name of workspace.

    Optional Parameters:
    - interval -- Polling interval in sec.
    '''
    return _call_az("az batchai job wait", locals())




'''
Manage KeyVault keys, secrets, and certificates.
'''
from .. pyaz_utils import _call_az
from . import backup, certificate, key, network_rule, private_endpoint_connection, private_link_resource, restore, secret, security_domain, storage


def create(resource_group, administrators=None, bypass=None, default_action=None, enable_purge_protection=None, enable_rbac_authorization=None, enable_soft_delete=None, enabled_for_deployment=None, enabled_for_disk_encryption=None, enabled_for_template_deployment=None, hsm_name=None, location=None, name=None, network_acls=None, network_acls_ips=None, network_acls_vnets=None, no_self_perms=None, no_wait=None, public_network_access=None, retention_days=None, sku=None, tags=None):
    '''
    Create a Vault or HSM.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - administrators -- [HSM Only] Administrator role for data plane operations for Managed HSM. It accepts a space separated list of OIDs that will be assigned.
    - bypass -- Bypass traffic for space-separated uses.
    - default_action -- Default action to apply when no rule matches.
    - enable_purge_protection -- Property specifying whether protection against purge is enabled for this vault. Setting this property to true activates protection against purge for this vault and its content - only the Key Vault service may initiate a hard, irrecoverable deletion. The setting is effective only if soft delete is also enabled. Enabling this functionality is irreversible - that is, the property does not accept false as its value.
    - enable_rbac_authorization -- Property that controls how data actions are authorized. When true, the key vault will use Role Based Access Control (RBAC) for authorization of data actions, and the access policies specified in vault properties will be  ignored (warning: this is a preview feature). When false, the key vault will use the access policies specified in vault properties, and any policy stored on Azure Resource Manager will be ignored. If null or not specified, the vault is created with the default value of false. Note that management actions are always authorized with RBAC.
    - enable_soft_delete -- [Vault Only] Property to specify whether the 'soft delete' functionality is enabled for this key vault. If it's not set to any value (true or false) when creating new key vault, it will be set to true by default. Once set to true, it cannot be reverted to false.
    - enabled_for_deployment -- [Vault Only] Property to specify whether Azure Virtual Machines are permitted to retrieve certificates stored as secrets from the key vault.
    - enabled_for_disk_encryption -- [Vault Only] Property to specify whether Azure Disk Encryption is permitted to retrieve secrets from the vault and unwrap keys.
    - enabled_for_template_deployment -- [Vault Only] Property to specify whether Azure Resource Manager is permitted to retrieve secrets from the key vault.
    - hsm_name -- Name of the HSM. (--hsm-name and --name/-n are mutually exclusive, please specify just one of them)
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- Name of the Vault.
    - network_acls -- Network ACLs. It accepts a JSON filename or a JSON string. JSON format: `{\"ip\":[<ip1>, <ip2>...],\"vnet\":[<vnet_name_1>/<subnet_name_1>,<subnet_id2>...]}`
    - network_acls_ips -- Network ACLs IP rules. Space-separated list of IP addresses.
    - network_acls_vnets -- Network ACLS VNet rules. Space-separated list of Vnet/subnet pairs or subnet resource ids.
    - no_self_perms -- [Vault Only] Don't add permissions for the current user/service principal in the new vault.
    - no_wait -- Do not wait for the long-running operation to finish.
    - public_network_access -- Property to specify whether the vault will accept traffic from public internet. If set to 'disabled' all traffic except private endpoint traffic and that originates from trusted services will be blocked. This will override the set firewall rules, meaning that even if the firewall rules are present we will not honor the rules.
    - retention_days -- Soft delete data retention days. It accepts >=7 and <=90.
    - sku -- Required. SKU details. Allowed values for Vault: premium, standard. Default: standard. Allowed values for HSM: Standard_B1, Custom_B32. Default: Standard_B1
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az keyvault create", locals())


def recover(hsm_name=None, location=None, name=None, no_wait=None, resource_group=None):
    '''
    Recover a Vault or HSM.

    Optional Parameters:
    - hsm_name -- Name of the deleted HSM. (--hsm-name and --name/-n are mutually exclusive, please specify just one of them)
    - location -- Location of the deleted Vault or HSM
    - name -- Name of the deleted Vault.
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- Resource group of the deleted Vault or HSM
    '''
    return _call_az("az keyvault recover", locals())


def list(resource_group=None, resource_type=None):
    '''
    List Vaults and/or HSMs.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_type -- When --resource-type is not present the command will list all Vaults and HSMs. Possible values for --resource-type are vault and hsm.
    '''
    return _call_az("az keyvault list", locals())


def show(hsm_name=None, name=None, resource_group=None):
    '''
    Show details of a Vault or HSM.

    Optional Parameters:
    - hsm_name -- Name of the HSM. (--hsm-name and --name/-n are mutually exclusive, please specify just one of them)
    - name -- Name of the Vault.
    - resource_group -- Proceed only if Key Vault belongs to the specified resource group.
    '''
    return _call_az("az keyvault show", locals())


def delete(hsm_name=None, name=None, no_wait=None, resource_group=None):
    '''
    Delete a Vault or HSM.

    Optional Parameters:
    - hsm_name -- Name of the HSM. (--hsm-name and --name/-n are mutually exclusive, please specify just one of them)
    - name -- Name of the Vault.
    - no_wait -- Do not wait for the long-running operation to finish.
    - resource_group -- Proceed only if Key Vault belongs to the specified resource group.
    '''
    return _call_az("az keyvault delete", locals())


def purge(hsm_name=None, location=None, name=None, no_wait=None):
    '''
    Permanently delete the specified Vault or HSM. Aka Purges the deleted Vault or HSM.

    Optional Parameters:
    - hsm_name -- Name of the deleted HSM. (--hsm-name and --name/-n are mutually exclusive, please specify just one of them)
    - location -- Location of the deleted Vault or HSM
    - name -- Name of the deleted Vault.
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az keyvault purge", locals())


def set_policy(name, application_id=None, certificate_permissions=None, key_permissions=None, no_wait=None, object_id=None, resource_group=None, secret_permissions=None, spn=None, storage_permissions=None, upn=None):
    '''
    Update security policy settings for a Key Vault.

    Required Parameters:
    - name -- Name of the Vault.

    Optional Parameters:
    - application_id -- Application ID of the client making request on behalf of a principal. Exposed for compound identity using on-behalf-of authentication flow.
    - certificate_permissions -- Space-separated list of certificate permissions to assign.
    - key_permissions -- Space-separated list of key permissions to assign.
    - no_wait -- Do not wait for the long-running operation to finish.
    - object_id -- a GUID that identifies the principal that will receive permissions
    - resource_group -- Proceed only if Key Vault belongs to the specified resource group.
    - secret_permissions -- Space-separated list of secret permissions to assign.
    - spn -- name of a service principal that will receive permissions
    - storage_permissions -- Space-separated list of storage permissions to assign.
    - upn -- name of a user principal that will receive permissions
    '''
    return _call_az("az keyvault set-policy", locals())


def delete_policy(name, application_id=None, no_wait=None, object_id=None, resource_group=None, spn=None, upn=None):
    '''
    

    Required Parameters:
    - name -- Name of the Vault.

    Optional Parameters:
    - application_id -- Application ID of the client making request on behalf of a principal. Exposed for compound identity using on-behalf-of authentication flow.
    - no_wait -- Do not wait for the long-running operation to finish.
    - object_id -- a GUID that identifies the principal that will receive permissions
    - resource_group -- Proceed only if Key Vault belongs to the specified resource group.
    - spn -- name of a service principal that will receive permissions
    - upn -- name of a user principal that will receive permissions
    '''
    return _call_az("az keyvault delete-policy", locals())


def list_deleted(resource_type=None):
    '''
    Get information about the deleted Vaults or HSMs in a subscription.

    Optional Parameters:
    - resource_type -- When --resource-type is not present the command will list all deleted Vaults and HSMs. Possible values for --resource-type are vault and hsm.
    '''
    return _call_az("az keyvault list-deleted", locals())


def show_deleted(hsm_name=None, location=None, name=None):
    '''
    Show details of a deleted Vault or HSM.

    Optional Parameters:
    - hsm_name -- Name of the deleted HSM. (--hsm-name and --name/-n are mutually exclusive, please specify just one of them)
    - location -- Location of the deleted Vault or HSM
    - name -- Name of the deleted Vault.
    '''
    return _call_az("az keyvault show-deleted", locals())


def update(name, add=None, bypass=None, default_action=None, enable_purge_protection=None, enable_rbac_authorization=None, enable_soft_delete=None, enabled_for_deployment=None, enabled_for_disk_encryption=None, enabled_for_template_deployment=None, force_string=None, no_wait=None, public_network_access=None, remove=None, resource_group=None, retention_days=None, set=None):
    '''
    Update the properties of a Vault.

    Required Parameters:
    - name -- Name of the Vault.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - bypass -- Bypass traffic for space-separated uses.
    - default_action -- Default action to apply when no rule matches.
    - enable_purge_protection -- Property specifying whether protection against purge is enabled for this vault. Setting this property to true activates protection against purge for this vault and its content - only the Key Vault service may initiate a hard, irrecoverable deletion. The setting is effective only if soft delete is also enabled. Enabling this functionality is irreversible - that is, the property does not accept false as its value.
    - enable_rbac_authorization -- Property that controls how data actions are authorized. When true, the key vault will use Role Based Access Control (RBAC) for authorization of data actions, and the access policies specified in vault properties will be  ignored (warning: this is a preview feature). When false, the key vault will use the access policies specified in vault properties, and any policy stored on Azure Resource Manager will be ignored. If null or not specified, the vault is created with the default value of false. Note that management actions are always authorized with RBAC.
    - enable_soft_delete -- [Vault Only] Property to specify whether the 'soft delete' functionality is enabled for this key vault. If it's not set to any value (true or false) when creating new key vault, it will be set to true by default. Once set to true, it cannot be reverted to false.
    - enabled_for_deployment -- [Vault Only] Property to specify whether Azure Virtual Machines are permitted to retrieve certificates stored as secrets from the key vault.
    - enabled_for_disk_encryption -- [Vault Only] Property to specify whether Azure Disk Encryption is permitted to retrieve secrets from the vault and unwrap keys.
    - enabled_for_template_deployment -- [Vault Only] Property to specify whether Azure Resource Manager is permitted to retrieve secrets from the key vault.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - no_wait -- Do not wait for the long-running operation to finish.
    - public_network_access -- Property to specify whether the vault will accept traffic from public internet. If set to 'disabled' all traffic except private endpoint traffic and that originates from trusted services will be blocked. This will override the set firewall rules, meaning that even if the firewall rules are present we will not honor the rules.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - resource_group -- Proceed only if Key Vault belongs to the specified resource group.
    - retention_days -- Soft delete data retention days. It accepts >=7 and <=90.
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az keyvault update", locals())


def wait(name, created=None, custom=None, deleted=None, exists=None, interval=None, resource_group=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the Vault is met.

    Required Parameters:
    - name -- Name of the Vault.

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - resource_group -- Proceed only if Key Vault belongs to the specified resource group.
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az keyvault wait", locals())


def update_hsm(hsm_name, add=None, bypass=None, default_action=None, enable_purge_protection=None, force_string=None, no_wait=None, remove=None, resource_group=None, secondary_locations=None, set=None):
    '''
    Update the properties of a HSM.

    Required Parameters:
    - hsm_name -- Name of the HSM.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - bypass -- Bypass traffic for space-separated uses.
    - default_action -- Default action to apply when no rule matches.
    - enable_purge_protection -- Property specifying whether protection against purge is enabled for this managed HSM pool. Setting this property to true activates protection against purge for this managed HSM pool and its content - only the Managed HSM service may initiate a hard, irrecoverable deletion. The setting is effective only if soft delete is also enabled. Enabling this functionality is irreversible.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - no_wait -- Do not wait for the long-running operation to finish.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - resource_group -- Proceed only if Key Vault belongs to the specified resource group.
    - secondary_locations -- --secondary-locations extends/contracts an HSM pool to listed regions. The primary location where the resource was originally created CANNOT be removed.
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az keyvault update-hsm", locals())


def wait_hsm(hsm_name, created=None, custom=None, deleted=None, exists=None, interval=None, resource_group=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the HSM is met.

    Required Parameters:
    - hsm_name -- Name of the HSM.

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - resource_group -- Proceed only if HSM belongs to the specified resource group.
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az keyvault wait-hsm", locals())




'''
Manage timer triggers for a task
'''
from .... pyaz_utils import _call_az

def add(name, registry, schedule, timer_name, enabled=None, resource_group=None):
    '''
    Add a timer trigger to a task.

    Required Parameters:
    - name -- The name of the task.
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`
    - schedule -- The schedule of the timer trigger represented as a cron expression.
    - timer_name -- The name of the timer trigger.

    Optional Parameters:
    - enabled -- Indicates whether the timer trigger is enabled.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr task timer add", locals())


def update(name, registry, timer_name, enabled=None, resource_group=None, schedule=None):
    '''
    Update the timer trigger for a task.

    Required Parameters:
    - name -- The name of the task.
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`
    - timer_name -- The name of the timer trigger.

    Optional Parameters:
    - enabled -- Indicates whether the timer trigger is enabled.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - schedule -- The schedule of the timer trigger represented as a cron expression.
    '''
    return _call_az("az acr task timer update", locals())


def remove(name, registry, timer_name, resource_group=None):
    '''
    Remove a timer trigger from a task.

    Required Parameters:
    - name -- The name of the task.
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`
    - timer_name -- The name of the timer trigger.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr task timer remove", locals())


def list(name, registry, resource_group=None):
    '''
    List all timer triggers for a task.

    Required Parameters:
    - name -- The name of the task.
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr task timer list", locals())




'''
List or show existing origins related to CDN endpoints.
'''
from ... pyaz_utils import _call_az

def show(endpoint_name, name, profile_name, resource_group):
    '''
    

    Required Parameters:
    - endpoint_name -- Name of the CDN endpoint.
    - name -- Name of the origin.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cdn origin show", locals())


def list(endpoint_name, profile_name, resource_group):
    '''
    

    Required Parameters:
    - endpoint_name -- Name of the CDN endpoint.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cdn origin list", locals())


def create(endpoint_name, host_name, name, profile_name, resource_group, disabled=None, http_port=None, https_port=None, origin_host_header=None, priority=None, private_link_approval_message=None, private_link_location=None, private_link_resource_id=None, weight=None):
    '''
    Create an origin.

    Required Parameters:
    - endpoint_name -- Name of the CDN endpoint.
    - host_name -- None
    - name -- Name of the origin.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - disabled -- None
    - http_port -- None
    - https_port -- None
    - origin_host_header -- None
    - priority -- None
    - private_link_approval_message -- None
    - private_link_location -- None
    - private_link_resource_id -- None
    - weight -- None
    '''
    return _call_az("az cdn origin create", locals())


def update(endpoint_name, name, profile_name, resource_group, disabled=None, host_name=None, http_port=None, https_port=None, origin_host_header=None, priority=None, private_link_approval_message=None, private_link_location=None, private_link_resource_id=None, weight=None):
    '''
    Update an origin.

    Required Parameters:
    - endpoint_name -- Name of the CDN endpoint.
    - name -- Name of the origin.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - disabled -- None
    - host_name -- None
    - http_port -- None
    - https_port -- None
    - origin_host_header -- None
    - priority -- None
    - private_link_approval_message -- None
    - private_link_location -- None
    - private_link_resource_id -- None
    - weight -- None
    '''
    return _call_az("az cdn origin update", locals())


def delete(endpoint_name, name, profile_name, resource_group, yes=None):
    '''
    

    Required Parameters:
    - endpoint_name -- Name of the CDN endpoint.
    - name -- Name of the origin.
    - profile_name -- Name of the CDN profile which is unique within the resource group.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az cdn origin delete", locals())

